#!/usr/bin/python
# -*- coding: iso-8859-1 -*-

# Mattricks, a free helper program for hattricks players.
# Copyright (C) 2003 Mattricks Team
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import sys
import os.path

# Basic error handling
def init_error_handling():
    class Err:
        def __init__(self, file, old_sys_err):
            self.file = file
            self.old_sys_err = old_sys_err
            self.this_exception = None

        def write(self, s):
            if self.file:
                self.file.write(s)
            self.old_sys_err.write(s)
            if self.this_exception is not getattr(sys, "last_traceback", None):
                self.this_exception = getattr(sys, "last_traceback", None)
                self.file.write("\n")

    dir = os.path.abspath(os.path.dirname(sys.argv[0]))
    filename = os.path.join(dir, "errorlog.txt")
    old_sys_err = sys.stderr
    try:
        file = open(filename, 'w')
    except:
        file = None
    sys.stderr = Err(file, old_sys_err)

# Internationalization
def init_i18n():
    from Mattricks import I18n

    I18n.install_translation()

def parse_and_start():
    # Option parsing
    import getopt

    from Mattricks.Config import config

    usage = _("""Usage: %s [general options] command [command-specific options]

Options:

  -h    --help          Show this help message and exit.
  -H    --help-command  Show help on options for the specified command.

        --version       Print version info and exit.

Commands:

  gui          Start up the gui. [The default]
  fetch        Fetch an hrf/xml-file and exit.
  listchanges  List the changes between two hrf-files and exit.
  maketeam     Let the computer generate a team from hrf and exit.
  table        Print a table from a fixture-xml and exit.

""") % sys.argv[0]

    try:
        (options, args) = getopt.getopt(sys.argv[1:], "hH",
                                        ["help",
                                         "help-command",
                                         #"datadir=",
                                         #"localedir=",
                                         "version"])
    except getopt.GetoptError, e:
        sys.stdout.write(str(e) + "\n\n")
        sys.stdout.write(usage)
        sys.exit(2)

    help_command = False
    for o, a in options:
        if o in ["-h", "--help"]:
            sys.stdout.write(usage)
            sys.exit()
        elif o in ["-H", "--help-command"]:
            help_command = True
        elif o in ["--version"]:
            from Mattricks import Version

            version_text = "Mattricks " + Version.version + "\n\n" + \
                           _("""Copyright (C) 2003 Mattricks Team
This is free software; see the source for copying conditions.  There is NO
warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
""")

            sys.stdout.write(version_text)
            sys.exit()

    all_commands = ["gui", "fetch", "listchanges", "maketeam", "table"]
    command = all_commands[0]

    if len(args) > 0:
        command = args[0]
        args = args[1:]

    if command not in all_commands:
        sys.stdout.write(_("Command %s not reconized.") % command + "\n\n")
        sys.stdout.write(usage)
        sys.exit(2)

    if command == "gui":
        # Start gui

        gui_usage = _("Usage: %s gui") % sys.argv[0] + "\n"

        if help_command:
            sys.stdout.write(gui_usage)
            sys.exit()

        try:
            from Mattricks import Main
        except ImportError, e:
            sys.stdout.write(_("Unable to import the Mattricks package.") + "\n\n")
            sys.stdout.write(str(e) + "\n")
            sys.exit()

        Main.main(*args)

    elif command == "fetch":
        fetch_usage = _("""Usage: %s fetch [options]

Options:

  -u USER    --user=USER         Specify the hattrick user (if
                                 omitted it is asked for).
  -p PASS    --pass=PASS         Specify the hattrick password (if
                                 omitted it is asked for).
  -t TYPE    --type=TYPE         Comma-separated list of file types
                                 to download.
  -d DIR     --target-dir=DIR    Directory to save in.
             --filename=FILE     Specify the filename.
             --server=IP         Specify the server IP address.
             --passwordfile=FILE A file contaning only loginname and
                                 password.

Download types:

  hrf       Download a hrf file.
  fixtures  Download a fixtures xml file.

Hrf type options:

  -a         --always            Always download a new hrf file.
  -A         --not-always        Only download a new hrf file if no
                                 hrf file exits for the day.
  -o         --override          Override day old hrf.
  -O         --unique-filename   Use a unique filename.

Fixtures type options:

  -l         --league-id         Comma-separated list of leagues to
                                 download.
  -s         --season            Comma-separated list of seasons to
                                 download.

""") % sys.argv[0]

        if help_command:
            sys.stdout.write(fetch_usage)
            sys.exit()

        try:
            (options, args) = getopt.getopt(args, "aAoOl:s:p:d:t:u:",
                                            ["always",
                                             "not-always",
                                             "override",
                                             "unique-filename",
                                             "filename=",
                                             "league-id=",
                                             "pass=",
                                             "passwordfile=",
                                             "season=",
                                             "server=",
                                             "target-dir=",
                                             "type=",
                                             "user="])
        except getopt.GetoptError, e:
            sys.stdout.write(str(e) + "\n\n")
            sys.stdout.write(fetch_usage)
            sys.exit(2)


        from Mattricks.Config import config
        import string

        loginname = None
        password = None
        path = config.get("Fetch", "save directory")
        filename = None
        adownload = config.get("Fetch", "always download")
        override = config.get("Fetch", "override old hrf")
        server = config.get("Fetch", "ip number")
        type_list = []
        leagueids = []
        seasons = []

        for o, a in options:
            if o in ["-u", "--user"]:
                loginname = a
            elif o in ["-p", "--pass"]:
                password = a
            elif o in ["--passwordfile"]:
                try:
                    passwordfile = open(a, 'r').read()
                    (loginname, password) = string.split(passwordfile, maxsplit = 1)
                    loginname = loginname.strip()
                    password = password.strip()
                except Exception, e:
                    sys.stdout.write(_("Couldn't get loginname and password") + ":\n" +
                                     str(e) + "\n\n")
                    sys.stdout.write(fetch_usage)
                    sys.exit(2)

            elif o in ["-d", "--target-dir"]:
                path = os.path.realpath(os.path.expanduser(a))
            elif o in ["--filename"]:
                filename = a
            elif o in ["--server"]:
                server = a
            elif o in ["-a", "--always"]:
                adownload = True
            elif o in ["-A", "--not-always"]:
                adownload = False
            elif o in ["-o", "--override"]:
                override = True
            elif o in ["-O", "--unique-filename"]:
                override = False
            elif o in ["-t", "--type"]:
                type_list = unique(type_list + string.split(a, ","))
            elif o in ["-l", "--league-id"]:
                try:
                    leagueids = [int(x) for x in string.split(a, ',')]
                except ValueError, e:
                    sys.stdout.write(_("Invalid league id list %s.") % a + "\n\n")
                    sys.stdout.write(fetch_usage)
                    sys.exit(2)
            elif o in ["-s", "--season"]:
                try:
                    seasons = [int(x) for x in string.split(a, ',')]
                except ValueError, e:
                    sys.stdout.write(_("Invalid season list %s.") % a + "\n\n")
                    sys.stdout.write(fetch_usage)
                    sys.exit(2)

        if type_list == []:
            type_list = ["hrf"]

        if not loginname:
            sys.stdout.write(_("Hattrick login name") + ": ")
            loginname = sys.stdin.readline().strip()

        if not password:
            import getpass
            password = getpass.getpass(_("Hattrick password") + ": ")

        from Mattricks import Fetch

        try:
            if "hrf" in type_list:
                result = Fetch.conn.fetch_hrf(loginname, password, path, None, filename,
                                              adownload, override, server)
            if "fixtures" in type_list:
                result = Fetch.conn.fetch_fixtures_xml(loginname, password, path, None, filename,
                                                       leagueids, seasons, server)
        except Fetch.FetchError, e:
            sys.stderr.write(_("Error") + ": " + str(e) + "\n")
            if e.extra_info:
                sys.stderr.write("\n" + e.extra_info + "\n")

    elif command == "listchanges":
        # Start listchanges

        import string
        from Mattricks import HRFData, Listchanges

        listchanges_usage = _("""Usage: %s listchanges [options] first_hrf second_hrf

Options:

  -f LIST    --filter=LIST   A comma separated list of filters.

Filters: %s
""") % (sys.argv[0], string.join(Listchanges.filters.keys(), ", "))

        if help_command:
            sys.stdout.write(listchanges_usage)
            sys.exit()

        try:
            (options, args) = getopt.getopt(args, "f:", ["filter="])
        except getopt.GetoptError, e:
            sys.stdout.write(str(e) + "\n\n")
            sys.stdout.write(listchanges_usage)
            sys.exit(2)

        filter_list = []
        for o, a in options:
            if o in ["-f", "--filter"]:
                filter_list = unique(filter_list + string.split(a, ","))

        for f in filter_list:
            if f not in Listchanges.filters.keys():
                sys.stdout.write(_("Filter type %s does not exist.") % f + "\n\n")
                sys.stdout.write(listchanges_usage)
                sys.exit(2)

        if len(args) != 2:
            sys.stdout.write(_("Wrong number of hrf files.") + "\n\n")
            sys.stdout.write(listchanges_usage)
            sys.exit(2)

        h1 = HRFData.HRFData(args[0])
        h2 = HRFData.HRFData(args[1])

        sys.stdout.write(Listchanges.Listchanges(h1, h2).get_changes_text(filter_list) + "\n")

    elif command == "maketeam":
        # Start maketeam

        maketeam_usage = _("Usage: %s maketeam hrffile") % sys.argv[0] + "\n"

        if help_command:
            sys.stdout.write(maketeam_usage)
            sys.exit()

        if len(args) != 1:
            sys.stdout.write(_("Wrong number of hrf files.") + "\n\n")
            sys.stdout.write(maketeam_usage)
            sys.exit(2)

        import string
        from Mattricks import TeamSelector, HRFData, Terms

        h1 = HRFData.HRFData(args[0])
        ts = TeamSelector.TeamSelector(h1)
        pt = ts.get_player_table()
        lineup = ts.select_team()

        for f, plist in pt.items():
            print
            print f.capitalize() + ":"
            print
            for val, pid in plist[:8]:
                print "%5.2f %s" % (val, h1.get_player(pid).name)

        print "\n" + _("Team") + ":\n"
        for descr, cpos, pos in TeamSelector.TeamSelector.lineup_info:
            print "%s %s %d %.2f %s" % (
                string.ljust(descr, 13),
                string.ljust(Terms.individual_order[lineup[cpos][4]] + ":", 16),
                lineup[cpos][2],
                lineup[cpos][1],
                h1.get_player(lineup[cpos][0], True).name)

        print "\n%s   %.2f" % (string.ljust(_("Team value") + ":", 30),
                               ts.de.teamval(lineup))

    elif command == "table":
        # Start table

        table_usage = _("""Usage: %s table [options] fixtures_xml

Options:

  -r ROUND   --round=ROUND   Print the table for this ROUND.
""") % sys.argv[0]

        if help_command:
            sys.stdout.write(table_usage)
            sys.exit()

        try:
            (options, args) = getopt.getopt(args, "r:", ["round="])
        except getopt.GetoptError, e:
            sys.stdout.write(str(e) + "\n\n")
            sys.stdout.write(table_usage)
            sys.exit(2)

        round = 14
        for o, a in options:
            if o in ["-r", "--round"]:
                try:
                    round = int(a)
                    if not (0 < round <= 14):
                        raise ValueError
                except ValueError, e:
                    sys.stdout.write(_("Round %s is not a valid round.") % a + "\n\n")
                    sys.stdout.write(table_usage)
                    sys.exit(2)

        if len(args) != 1:
            sys.stdout.write(_("Wrong number of hrf files.") + "\n\n")
            sys.stdout.write(table_usage)
            sys.exit(2)

        from Mattricks import XMLData

        XMLData.parse_fixtures(args[0]).write_table_text(sys.stdout, round)

if __name__ == "__main__":
    init_error_handling()
    init_i18n()
    from Mattricks.Common import *
    parse_and_start()

