# -*- coding: iso-8859-1 -*-

# Mattricks, a free helper program for hattricks players.
# Copyright (C) 2003 Mattricks Team
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import string
import time
import re
import sys
import math
import operator

import Version

if sys.version < '2.2.1':
    True = 1
    False = 0
    def bool(val=False):
        if val == False:
            return False
        else:
            return True
    print True

def version_str():
    return (_("This is Mattricks %s") % Version.version,
            _("It runs under python %s on %s") % (sys.version, sys.platform))

def string2time(tstring):
    r = re.compile("([0-9]{1,4})-([0-9]{1,2})-([0-9]{1,2}) ([0-9]{2}):([0-9]{2}):([0-9]{2})")
    m = r.match(tstring)
    if not m:
        return -1

    res = m.group(1,2,3,4,5,6)
    return time.mktime(tuple([int(x) for x in res]) + (0, 0, -1))

def name2surname(name_string):
    """Make a surname string from a name string.

    Assumes that the person just have one first name.
    'Adam Adamsson' => 'Adamsson, Adam'"""

    name = string.split(name_string, " ", 1)
    name.reverse()
    return string.join(name, ", ")

def unique(the_list):
    res = []
    for l in the_list:
        if not l in res:
            res.append(l)
    return res

def mktimestring(ctime):
    return time.strftime("%A, %d %b %Y %H:%M:%S", time.localtime(ctime)).capitalize()

def htdata_text(htdata):
    if htdata == (None, None):
        return "\n\n"
    text = _("Date") + ": %s\n" % mktimestring(htdata[1].get_section("basics").date) + \
           _("File") + ": %s\n" % htdata[0] + \
           _("Team") + ": %s" % htdata[1].get_section("basics").teamName
    return text

class dict2func:
    def __init__(self, d):
        self.d = d

    def __call__(self, key):
        return self.d[key]

# Make a money string
def add_currency_to_money(amount, currency, is_prefix, always_sign = False):
    if always_sign:
        sign = {True: "-", False: "+"}[bool(amount < 0)]
    else:
        sign = {True: "-", False: ""}[bool(amount < 0)]
    amount = string.join(split_equal(str(abs(amount)), 3, True), " ")
    if is_prefix:
        return sign + currency + amount
    else:
        return sign + amount + " " + currency

# Return a string with explicit sign for numbers
def signedstr(value):
    if value > 0:
        text = ("+" + str(value))
    else:
        text = str(value)
    return text

# Split a string or list in equal places
def split_equal(mlist, size, reverse = False):
    res = []
    pos = 0
    while pos < len(mlist):
        if reverse:
            if pos == 0:
                res.insert(0,mlist[-(pos+size):])
            else:
                res.insert(0,mlist[-(pos+size):-pos])
        else:
            res.append(mlist[pos:pos+size])
        pos += size
    return res

# True if any of the elements in the sequence also exists in sequence b.
def any_in(a,b):
    reduce(operator.or_, [(i in b) for i in a])

# Returns the density function of the normal distribution.
def normal_distribution(m = 0.0, sigma = 1.0):
    if sigma == 0.0:
        return (lambda x: 1.0)
    t = 1.0/(sigma*math.sqrt(2.0*math.pi))
    d = -1.0/(2.0*sigma*sigma)
    return (lambda x, m=m, t=t, d=d: t*math.exp(pow((float(x)-m),2)*d))

def binomial_coefficient(n, k):
    if k == 0 or k == n:
        return 1

    x = reduce(operator.mul, range(n-k+1, n+1))
    y = reduce(operator.mul, range(1, k+1))

    return x // y

# Returns the probability function of the binomial distribution.
def binomial_distribution(n, p):
    return (lambda k, n=n, p=p: binomial_coefficient(n,k)*pow(p,k)*pow(1.0-p,n-k))
