# -*- coding: iso-8859-1 -*-

# Mattricks, a free helper program for hattricks players.
# Copyright (C) 2003 Mattricks Team
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import time

import Listchanges
import HRFData
import SelectDateMenu
from Common import *

from wxPython.wx import *

class ComparisonPage(wxPanel):
    ID_EARLY_DATE_MENU     = 221
    ID_LATE_DATE_MENU      = 222
    ID_EARLY_DATE_SELECTED = 223
    ID_LATE_DATE_SELECTED  = 224
    ID_NO_FILTER           = 225

    def __init__(self, parent, ID):
        f2 = HRFData.htdirs.get_from_time(time.time())
        if f2 == None:
            self.early_htdata = (None, None)
            self.late_htdata = (None, None)
        else:
            self.late_htdata = (f2, HRFData.hrfstorage[f2])
            ed = self.late_htdata[1].get_section("basics").date - 7 * 86400 # One week ago
            f1 = HRFData.htdirs.get_from_time(ed)
            if f1 == None:
                self.early_htdata = (None, None)
                self.late_htdata = (None, None)
            else:
                self.early_htdata = (f1, HRFData.hrfstorage[f1])

        wxPanel.__init__(self, parent, ID)

        sizer = wxBoxSizer(wxVERTICAL)
        hsizer = wxBoxSizer(wxHORIZONTAL)

        self.httexts = []
        self.date_buttons = []
        for first, id, text in [(True, ComparisonPage.ID_EARLY_DATE_MENU, _("First date")), \
                                (False, ComparisonPage.ID_LATE_DATE_MENU, _("Second date"))]:
            vsizer = wxBoxSizer(wxVERTICAL)

            self.date_buttons.append(wxButton(self, id, text, style = wxBU_EXACTFIT))
            vsizer.Add(self.date_buttons[-1], 0, wxALL, 5)

            self.httexts.append(wxStaticText(self, -1, self.__get_date_text(first)))
            vsizer.Add(self.httexts[-1], 1, wxEXPAND | wxALL, 5)

            hsizer.AddSizer(vsizer, 1, wxEXPAND | wxALIGN_CENTRE | wxALL, 0)

        sizer.AddSizer(hsizer, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 0)

        hsizer = wxBoxSizer(wxHORIZONTAL)

        self.no_filter = wxCheckBox(self, ComparisonPage.ID_NO_FILTER, _("No filter"))
        self.no_filter.SetValue(False)
        hsizer.Add(self.no_filter, 1, wxEXPAND | wxALIGN_CENTRE | wxALL, 2)
        EVT_CHECKBOX(self, ComparisonPage.ID_NO_FILTER, self.NoFilterChanged)

        vsizer = wxBoxSizer(wxVERTICAL)

        default_filters = ["arena", "basics", "club", "league", "team",
                           "player", "player_attr", "player_value"]

        self.filter_cb = {}
        c = len(Listchanges.filters.keys()) / 2
        i = 0
        j = 0
        isizer = None
        for f in Listchanges.filters.keys():
            if i == 0 and isizer == None:
                isizer = wxBoxSizer(wxHORIZONTAL)

            self.filter_cb[f] = wxCheckBox(self, j + 230, Listchanges.filters[f][1])
            self.filter_cb[f].SetValue(f in default_filters)
            isizer.Add(self.filter_cb[f], 1, wxEXPAND | wxALIGN_CENTRE | wxALL, 2)
            EVT_CHECKBOX(self, j + 230, self.OnFilterChanged)

            if i == c-1 and isizer != None:
                vsizer.AddSizer(isizer, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 0)
                isizer = None
            i = (i+1) % c
            j += 1

        if isizer != None:
            vsizer.AddSizer(isizer, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 0)

        hsizer.AddSizer(vsizer, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 0)
        sizer.AddSizer(hsizer, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 0)

        self.textarea = wxTextCtrl(self, -1, style = wxHSCROLL | wxTE_MULTILINE | wxTE_READONLY)
        self.textarea.AppendText(self.__get_change_text())
        sizer.Add(self.textarea, 1, wxEXPAND | wxALIGN_CENTRE | wxALL, 5)

        self.SetSizer(sizer)
        self.SetAutoLayout(True)
        sizer.Fit(self)

        EVT_BUTTON(self, ComparisonPage.ID_EARLY_DATE_MENU, self.OnPopupMenu)
        EVT_BUTTON(self, ComparisonPage.ID_LATE_DATE_MENU, self.OnPopupMenu)

    def ChangeHRF(self, hrffile):
        if self.early_htdata == (None, None) or \
               self.late_htdata == (None, None):
            self.__change_hrf(hrffile, False)
            ed = self.late_htdata[1].get_section("basics").date - 7 * 86400 # One week ago
            self.__change_hrf(HRFData.htdirs.get_from_time(ed))

    def OnPopupMenu(self, event):
        first = (event.GetId() == ComparisonPage.ID_EARLY_DATE_MENU)
        if first:
            sel_id = ComparisonPage.ID_EARLY_DATE_SELECTED
            rect = self.date_buttons[0].GetRect()
            hrf = self.early_htdata[0]
        else:
            sel_id = ComparisonPage.ID_LATE_DATE_SELECTED
            rect = self.date_buttons[1].GetRect()
            hrf = self.late_htdata[0]
        sdmenu = SelectDateMenu.SelectDateMenu(self, sel_id, hrf)
        SelectDateMenu.EVT_DATE_SELECTED(sdmenu, sel_id, self.OnDateSelected)
        self.PopupMenu(sdmenu, (rect[0], rect[1] + rect[3]))

    def OnDateSelected(self, event):
        first = (event.GetId() == ComparisonPage.ID_EARLY_DATE_SELECTED)
        self.__change_hrf(event.GetHRFFile(), first)

    def NoFilterChanged(self, event):
        enabled = not self.no_filter.GetValue()
        for f, fcb in self.filter_cb.items():
            fcb.Enable(enabled)
        self.OnFilterChanged(event)

    def OnFilterChanged(self, event):
        self.textarea.Clear()
        self.textarea.AppendText(self.__get_change_text())
        self.textarea.SetInsertionPoint(0)

    def __change_hrf(self, hrffile, first = True):
        if first:
            self.early_htdata = (hrffile, HRFData.hrfstorage[hrffile])
            self.httexts[0].SetLabel(self.__get_date_text(True))
        else:
            self.late_htdata = (hrffile, HRFData.hrfstorage[hrffile])
            self.httexts[1].SetLabel(self.__get_date_text(False))
        self.textarea.Clear()
        self.textarea.AppendText(self.__get_change_text())
        self.textarea.SetInsertionPoint(0)

    def __get_change_text(self):
        if self.early_htdata == (None, None) or \
               self.late_htdata == (None, None):
            return ""
        filter_list = []
        if not self.no_filter.GetValue():
            for f, fcb in self.filter_cb.items():
                if fcb.GetValue():
                    filter_list.append(f)
        return Listchanges.Listchanges(self.early_htdata[1], \
                                       self.late_htdata[1]).get_changes_text(filter_list)

    def __get_date_text(self, first = True):
        if first:
            return htdata_text(self.early_htdata)
        return htdata_text(self.late_htdata)
