# -*- coding: iso-8859-1 -*-

# Mattricks, a free helper program for hattricks players.
# Copyright (C) 2003 Mattricks Team
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from Common import *
import Terms

class CurrentHTData:
    def __init__(self):
        self.htdata = None

current_htdata = CurrentHTData()

# This is uses current_htdata and is just a short for lots of lambdas.
def add_currency(amount_of_money, alwaysSign=False):
    lid = current_htdata.htdata.get_section("basics").leagueID
    (htname, name, currency, is_prefix, exchangerate, flag) = country_info[lid]
    return add_currency_to_money(amount_of_money, currency, is_prefix, alwaysSign)

# data_info structure:
# {section: {data_name: (hrf_name, description, convert_func, display_func), ...}, ...}
#
# section: Corresponding to the section of the hrf file.
# data_name: The name of the attribute in the resulting structure.
# hrf_name: The name of the attribute in the hrf file.
#
# Those below might be None, which means that they aren't used.
#
# description: A descritpion of the attribute intended to be read by the users.
# convert_func: A function to convert the value into the correct format.
# display_func: A function to convert the value into a user readable form.

known_general_data_info = {

    "arena":
    {'antalSitt': ('antalSitt', _('Basic seating'), int, None),
     'antalStaplats': ('antalStaplats', _('Terraces'), int, None),
     'antalTak': ('antalTak', _('Roofed seating'), int, None),
     'antalVIP': ('antalVIP', _('Seating in VIP boxes'), int, None),
     'arenaname': ('arenaname', _('Name of arena'), None, None),
     'expandingSitt': ('expandingSitt', _('Expanding of basic seating'), int, None),
     'expandingStaplats': ('expandingStaplats', _('Expanding of terraces'), int, None),
     'expandingTak': ('expandingTak', _('Expanding of roofed seating'), int, None),
     'expandingVIP': ('expandingVIP', _('Expanding of seating in VIP boxes'), int, None),
     'isExpanding': ('isExpanding', _('Is expanding'), int, dict2func(Terms.expanding)),
     'seatTotal': ('seatTotal', _('Total capacity'), int, None)},

    "basics":
    {'application': ('application', None, None, None),
     'appversion': ('appversion', None, None, None),
     'countryID': ('countryID', _('Country'), int, (lambda cid: country_info[Terms.country[cid]][1])),
     'date': ('date', _('Date'), string2time, mktimestring),
     'leagueID': ('leagueID', _('League'), int, (lambda lid: country_info[lid][1])),
     'matchround': ('matchround', _('Round'), int, None),
     'owner': ('owner', _('Owner'), None, None),
     'ownerEmail': ('ownerEmail', _("Owner's email"), None, None),
     'ownerHomepage': ('ownerHomepage', _("Owner's homepage"), None, None),
     'ownerICQ': ('ownerICQ', _("Owner's ICQ"), None, None),
     'season': ('season', _('Season'), int, None),
     'teamID': ('teamID', _('Team ID'), int, None),
     'teamName': ('teamName', _('Team name'), None, None)},

    "club":
    {'ekonom': ('ekonom', _('Economists'), int, None),
     'fanclub': ('fanclub', _('Supporters'), int, None),
     'hjTranare': ('hjTranare', _('Assistant coaches'), int, None),
     'juniorverksamhet': ('juniorverksamhet', _('Youth squad'), int, None),
     'lakare': ('lakare', _('Doctors'), int, None),
     'massor': ('massor', _('Physiotherapists'), int, None),
     'mvTranare': ('mvTranare', _('Goalkeeper coaches'), int, None),
     'presstalesman': ('presstalesman', _('Spokepersons'), int, None),
     'psykolog': ('psykolog', _('Psychologists'), int, None),
     'undefeated': ('undefeated', _('Undefeated'), int, None),
     'victories': ('victories', _('Victories'), int, None)},

    "economy":
    {'IncomeSponsorer': ('IncomeSponsorer', _('Sponsor revenue'), int, add_currency),
     'cash': ('cash', _('Cash'), int, add_currency),
     'costsArena': ('costsArena', _('Arena expenses'), int, add_currency),
     'costsJuniorverksamhet': ('costsJuniorverksamhet', _('Expenses for the youth squad'), int, add_currency),
     'costsPersonal': ('costsPersonal', _('Staff expenses'), int, add_currency),
     'costsRantor': ('costsRantor', _('Interests'), int, add_currency),
     'costsSpelare': ('costsSpelare', _('Player salaries'), int, add_currency),
     'costsSumma': ('costsSumma', _('Total expenses'), int, add_currency),
     'costsTillfalliga': ('costsTillfalliga', _('Temporary expenses'), int, add_currency),
     'incomeFinansiella': ('incomeFinansiella', _('Financial revenue'), int, add_currency),
     'incomePublik': ('incomePublik', _('Gate receipts'), int, add_currency),
     'incomeSumma': ('incomeSumma', _('Total revenue'), int, add_currency),
     'incomeTillfalliga': ('incomeTillfalliga', _('Temporary revenue'), int, add_currency),
     'lastCostsArena': ('lastCostsArena', _("Last week's arena expenses"), int, add_currency),
     'lastCostsJuniorverksamhet': ('lastCostsJuniorverksamhet', _("Last week's expenses for the youth sqyad"), int, add_currency),
     'lastCostsPersonal': ('lastCostsPersonal', _("Last week's staff expenses"), int, add_currency),
     'lastCostsRantor': ('lastCostsRantor', _("Last week's interests"), int, add_currency),
     'lastCostsSpelare': ('lastCostsSpelare', _("Last week's player salaries"), int, add_currency),
     'lastCostsSumma': ('lastCostsSumma', _('Total expenses of last week'), int, add_currency),
     'lastCostsTillfalliga': ('lastCostsTillfalliga', _("Last week's temporary expenses"), int, add_currency),
     'lastIncomeFinansiella': ('lastIncomeFinansiella', _("Last week's financial revenue"), int, add_currency),
     'lastIncomePublik': ('lastIncomePublik', _("Last week's gate receipts"), int, add_currency),
     'lastIncomeSponsorer': ('lastIncomeSponsorer', _("Last week's sponsor revenue"), int, add_currency),
     'lastIncomeSumma': ('lastIncomeSumma', _("Total revenue of last week"), int, add_currency),
     'lastIncomeTillfalliga': ('lastIncomeTillfalliga', _("Last week's temporary revenue"), int, add_currency),
     'lastTotal': ('lastTotal', _("Last week's profit"), int, add_currency),
     'sponsors': ('sponsors', _('Sponsors'), int, dict2func(Terms.sponsors_and_supporters)),
     'supporters': ('supporters', _('Supporters'), int, dict2func(Terms.sponsors_and_supporters)),
     'total': ('total', _('Profit'), int, add_currency)},

    "league":
    {'gjorda': ('gjorda', _('Scored goals'), int, None),
     'inslappta': ('inslappta', _('Opponents scored goals'), int, None),
     'placering': ('placering', _('League position'), int, None),
     'poang': ('poang', _('Points'), int, None),
     'serie': ('serie', _('Series'), None, None),
     'spelade': ('spelade', _('Played games'), int, None)},

    "lineup":
    {'behForward1': ('behForward1', _('Individual order forward 1'), int, dict2func(Terms.individual_order)),
     'behForward2': ('behForward2', _('Individual order forward 2'), int, dict2func(Terms.individual_order)),
     'behInsideBack1': ('behInsideBack1', _('Individual order central defender 1'), int, dict2func(Terms.individual_order)),
     'behInsideBack2': ('behInsideBack2', _('Individual order central defender 2'), int, dict2func(Terms.individual_order)),
     'behInsideMid1': ('behInsideMid1', _('Individual order midfielder 1'), int, dict2func(Terms.individual_order)),
     'behInsideMid2': ('behInsideMid2', _('Individual order midfielder 2'), int, dict2func(Terms.individual_order)),
     'behLeftBack': ('behLeftBack', _('Individual order left wingback'), int, dict2func(Terms.individual_order)),
     'behLeftWinger': ('behLeftWinger', _('Individual order left winger'), int, dict2func(Terms.individual_order)),
     'behRightBack': ('behRightBack', _('Individual order right wingback'), int, dict2func(Terms.individual_order)),
     'behRightWinger': ('behRightWinger', _('Individual order right winger'), int, dict2func(Terms.individual_order)),
     'captain': ('captain', _('Captain'), int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'forward1': ('forward1', _('Forward 1'), int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'forward2': ('forward2', _('Forward 2'), int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'insideBack1': ('insideBack1', _('Central defender 1'), int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'insideBack2': ('insideBack2', _('Central defender 2'), int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'insideMid1': ('insideMid1', _('Midfielder 1'), int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'insideMid2': ('insideMid2', _('Midfielder 2'), int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'installning': ('installning', _('Attitude'), int, dict2func(Terms.attitude)),
     'keeper': ('keeper', _('Goalkeeper'), int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'kicker1': ('kicker1', _('Freekick taker'), int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'leftBack': ('leftBack', _('Left wingback'), int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'leftWinger': ('leftWinger', _('Left winger'), int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'rightBack': ('rightBack', _('Right wingback'), int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'rightWinger': ('rightWinger', _('Right winger'), int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'substBack': ('substBack', _('Substitute defender'), int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'substForward': ('substForward', _('Substitute forward'), int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'substInsideMid': ('substInsideMid', _('Substitute midfielder'), int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'substKeeper': ('substKeeper', _('Substitute goalkeeper'), int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'substWinger': ('substWinger', _('Substitute winger'), int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'trainer': ('trainer', _('Coach'), int, (lambda pid: current_htdata.htdata.get_player(pid).name))},

    "team":
    {'exper343': ('exper343', _('Experience of 3-4-3'), int, dict2func(Terms.formation_experience)),
     'exper352': ('exper352', _('Experience of 3-5-2'), int, dict2func(Terms.formation_experience)),
     'exper433': ('exper433', _('Experience of 4-3-3'), int, dict2func(Terms.formation_experience)),
     'exper451': ('exper451', _('Experience of 4-5-1'), int, dict2func(Terms.formation_experience)),
     'exper532': ('exper532', _('Experience of 5-3-2'), int, dict2func(Terms.formation_experience)),
     'exper541': ('exper541', _('Experience of 5-4-1'), int, dict2func(Terms.formation_experience)),
     'sjalvfortroende': ('sjalvfortroende', _('Confidence'), None, None),
     'sjalvfortroendeValue': ('sjalvfortroendeValue', _('Confidence'), int, dict2func(Terms.team_self_confidence)),
     'stamning': ('stamning', _('Team spirit'), None, None),
     'stamningValue': ('stamningValue', _('Team spirit'), int, dict2func(Terms.team_spirit)),
     'trLevel': ('trLevel', _('Training level'), int, (lambda age: str(age) + " %")),
     'trType': ('trType', _('Training type'), None, None),
     'trTypeValue': ('trTypeValue', _('Training type'), int, dict2func(Terms.training_type)),

    # Team selecting things.
     'teamval': (None, _('Team value'), int, None)}

    }

known_player_data_info = {
    'Aggressiveness': ('Aggressiveness', _('Aggressiveness'), int, dict2func(Terms.aggressiveness)),
    'AggressivenessLabel': ('AggressivenessLabel', _('Aggressiveness'), None, None),
    'CountryID': ('CountryID', _('Country'), int, (lambda cid: country_info[Terms.country[cid]][1])),
    'TrainerSkill': ('TrainerSkill', _('Coaching ability'), int, dict2func(Terms.coach_skills)),
    'TrainerType': ('TrainerType', _('Coach type'), int, dict2func(Terms.coach_type)),
    'ald': ('ald', _('Age'), int, (lambda age: ngettext("%d year", "%d years", age) % age)),
    'bac': ('bac', _('Defending'), int, dict2func(Terms.player_abilities)),
    'fas': ('fas', _('Set pieces'), int, dict2func(Terms.player_abilities)),
    'for': ('for', _('Form'), int, dict2func(Terms.player_abilities)),
    'fra': ('fra', _('Passing'), int, dict2func(Terms.player_abilities)),
    'gentleness': ('gentleness', _('Gentleness'), int, dict2func(Terms.agreeability)),
    'gentlenessLabel': ('gentlenessLabel', _('Gentleness'), None, None),
    'gev': ('gev', _('Total competition goals'), int, (lambda goals: ngettext("%d goal", "%d goals", goals) % goals)),
    'gtc': ('gtc', _('Cup goals'), int, (lambda goals: ngettext("%d goal", "%d goals", goals) % goals)),
    'gtl': ('gtl', _('League goals'), int, (lambda goals: ngettext("%d goal", "%d goals", goals) % goals)),
    'gttot': (None, _('Competition goals'), int, (lambda goals: ngettext("%d goal", "%d goals", goals) % goals)),
    'gtt': ('gtt', _('Friendly goals'), int, (lambda goals: ngettext("%d goal", "%d goals", goals) % goals)),
    'gtall': (None, _('Total goals'), int, (lambda goals: ngettext("%d goal", "%d goals", goals) % goals)),
    'hat': ('hat', _('Hattricks'), int, (lambda ht: ngettext("%d hattrick", "%d hattricks", ht) % ht)),
    'honesty': ('honesty', _('Honesty'), int, dict2func(Terms.honesty)),
    'honestyLabel': ('honestyLabel', _('Honesty'), None, None),
    'led': ('led', _('Leadership'), int, dict2func(Terms.player_abilities)),
    'mal': ('mal', _('Scoring'), int, dict2func(Terms.player_abilities)),
    'mkt': ('mkt', _('Assessed value'), int, add_currency),
    'mlv': ('mlv', _('Goalkeeper'), int, dict2func(Terms.player_abilities)),
    'name': ('name', _('Name'), None, None),
    'rating' : ('rating', _('Latest rating'), int, (lambda stars: str(float(stars)/2) + "*")),
    'playerID': (None, _('Player identity'), int, None),
    'rut': ('rut', _('Experience'), int, dict2func(Terms.player_abilities)),
    'sal': ('sal', _('Salary'), int, add_currency),
    'ska': ('ska', _('Injury'), int, dict2func(Terms.injury)), # Maybe a func for getting images?
    'spe': ('spe', _('Playmaking'), int, dict2func(Terms.player_abilities)),
    'speciality': ('speciality', _('Speciality'), int, dict2func(Terms.speciality)),
    'specialityLabel': ('specialityLabel', _('Speciality'), None, None),
    'surname': ('name', _('Surname'), name2surname, None),
    'uth': ('uth', _('Stamina'), int, dict2func(Terms.player_abilities)),
    'warnings': ('warnings', _('Bookings'), int, None), # Maybe a func for getting images?
    'ytt': ('ytt', _('Winger'), int, dict2func(Terms.player_abilities)),

    # Team selecting things.
    "ts_goalie": (None, _('Goalkeeper'), None, (lambda x: "%.2f (%d)" % x)),
    "ts_centraldefender": (None, _('Central defender'), None, (lambda x: "%.2f (%d)" % x)),
    "ts_centraldefender_offensive": (None, _('Offensive central defender'), None, (lambda x: "%.2f (%d)" % x)),
    "ts_centraldefender_towards_the_wing": (None, _('Central defender, towards the wing'), None, (lambda x: "%.2f (%d)" % x)),
    "ts_wingback": (None, _('Wingback'), None, (lambda x: "%.2f (%d)" % x)),
    "ts_wingback_offensive": (None, _('Offensive wingback'), None, (lambda x: "%.2f (%d)" % x)),
    "ts_wingback_defensive": (None, _('Defensive wingback'), None, (lambda x: "%.2f (%d)" % x)),
    "ts_wingback_towards_the_middle": (None, _('Wingback, towards the middle'), None, (lambda x: "%.2f (%d)" % x)),
    "ts_innermid": (None, _('Midfielder'), None, (lambda x: "%.2f (%d)" % x)),
    "ts_innermid_offensive": (None, _('Offensive midfielder'), None, (lambda x: "%.2f (%d)" % x)),
    "ts_innermid_defensive": (None, _('Defensive midfielder'), None, (lambda x: "%.2f (%d)" % x)),
    "ts_innermid_towards_the_wing": (None, _('Midfielder, towards the wing'), None, (lambda x: "%.2f (%d)" % x)),
    "ts_winger": (None, _('Winger'), None, (lambda x: "%.2f (%d)" % x)),
    "ts_winger_offensive": (None, _('Offensive winger'), None, (lambda x: "%.2f (%d)" % x)),
    "ts_winger_defensive": (None, _('Defensive winger'), None, (lambda x: "%.2f (%d)" % x)),
    "ts_winger_towards_the_middle": (None, _('Winger, towards the middle'), None, (lambda x: "%.2f (%d)" % x)),
    "ts_forward": (None, _('Forward'), None, (lambda x: "%.2f (%d)" % x)),
    "ts_forward_defensive": (None, _('Defensive forward'), None, (lambda x: "%.2f (%d)" % x)),
    "ts_best_position": (None, _('Best position'), None, \
                         (lambda x: "%s (%.2f)" % (Terms.team_positions[x[0]][1], x[1]))),
    }


# country_info : Contains country related information
# leagueID : ( HT-name, local name, currency, is_prefix?, exchange rate related to Sverige, flag name)
country_info = {
    0:  ('Unknown', _('Unknown'), 'Unknown', False, 1, None),
    1:  ('Sverige', _('Sweden'), 'kr', False, 1, 'flag_sverige.png'),
    2:  ('England', _('England'), '', True, 15, 'flag_england.png'),
    3:  ('Deutschland', _('Germany'), 'Euro', False, 10, 'flag_deutschland.png'),
    4:  ('Italia', _('Italy'), 'Euro', False, 10, 'flag_italia.png'),
    5:  ('France', _('France'), 'Euro', False, 10, 'flag_france.png'),
    6:  ('Mxico', _('Mexico'), 'Pesos', False, 1, 'flag_mexico.png'),
    7:  ('Argentina', _('Argentina'), 'Pesos', False, 10, 'flag_argentina.png'),
    8:  ('USA', _('USA'), '$', True, 10, 'flag_usa.png'),
    9:  ('Norge', _('Norway'), 'kr', False, 1, 'flag_norge.png'),
    11: ('Danmark', _('Denmark'), 'kr', False, 1, 'flag_danmark.png'),
    12: ('Suomi', _('Finland'), 'Euro', False, 10, 'flag_suomi.png'),
    14: ('Nederland', _('Netherlands'), 'Euro', False, 10, 'flag_nederland.png'),
    15: ('Oceania', _('Oceania'), 'AU$', False, 5, 'flag_oceania.png'),
    16: ('Brasil', _('Brazil'), 'Real', False, 5, 'flag_brasil.png'),
    17: ('Canada', _('Canada'), 'C$', False, 5, 'flag_canada.png'),
    18: ('Chile', _('Chile'), 'Pesos', False, 0.05, 'flag_chile.png'),
    19: ('Colombia', _('Colombia'), 'Dollar', False, 1, 'flag_colombia.png'),
    20: ('India', _('India'), 'Rupees', False, 0.25, 'flag_india.png'),
    21: ('Ireland', _('Ireland'), 'Euro', False, 10, 'flag_ireland.png'),
    22: ('Nippon', _('Japan'), 'Yen', False, 0.1, 'flag_nippon.png'),
    23: ('Peru', _('Peru'), '$', True, 1, 'flag_peru.png'),
    24: ('Polska', _('Poland'), 'Zloty', False, 2.5, 'flag_polska.png'),
    25: ('Portugal', _('Portugal'), 'Euro', False, 10, 'flag_portugal.png'),
    26: ('Scotland', _('Scotland'), '', True, 15, 'flag_scotland.png'),
    27: ('South Africa', _('South Africa'), 'Rand', False, 1.25, 'flag_south_africa.png'),
    28: ('Uruguay', _('Uruguay'), 'Pesos', False, 1, 'flag_uruguay.png'),
    29: ('Venezuela', _('Venezuela'), 'Bolivares', False, 10, 'flag_venezuela.png'),
    30: ('South Korea', _('South Korea'), 'Won', False, 0.01, 'flag_south_korea.png'),
    31: ('Prathet Thai', _('Thailand'), 'Baht', False, 0.25, 'flag_prathet_thai.png'),
    32: ('Trkiye', _('Turkey'), 'Lira', False, 10, 'flag_turkiye.png'),
    33: ('Egypt', _('Egypt'), 'E', False, 2.5, 'flag_egypt.png'),
    34: ('China', _('China'), 'Yuan', False, 1, 'flag_china.png'),
    35: ('Rossiya', _('Russia'), 'Roubel', False, 0.25, 'flag_rossiya.png'),
    36: ('Espaa', _('Spain'), 'Euro', False, 10, 'flag_espana.png'),
    37: ('Romnia', _('Romania'), 'Lei', False, 0.5, 'flag_romania.png'),
    38: ('Island', _('Iceland'), 'Ikr', False, 0.1, 'flag_island.png'),
    39: ('sterreich', _('Austria'), 'Euro', False, 10, 'flag_osterreich.png'),
    44: ('Belgi', _('Belgium'), 'Euro', False, 10, 'flag_belgie.png'),
    45: ('Malaysia', _('Malaysia'), 'MYR', False, 2.5, 'flag_malaysia.png'),
    46: ('Schweiz', _('Switzerland'), 'CHF', False, 5, 'flag_schweiz.png'),
    47: ('Singapore', _('Singapore'), 'SG$', False, 5, 'flag_singapore.png'),
    50: ('Hellas', _('Greece'), 'Euro', False, 10, 'flag_hellas.png'),
    51: ('Magyarorszg', _('Hungary'), 'eFt', False, 50, 'flag_hungary.png'),
    52: ('Ceska republik', _('Czech Republic'), 'Koruny', False, 0.25, 'flag_ceska.png'),
    53: ('Latvija', _('Latvia'), 'Lats', False, 20, 'flag_latvija.png'),
    54: ('Indonesia', _('Indonesia'), 'Rp', False, 0.001, 'flag_indonesia.png'),
    55: ('Pilipinas', _('Philippines'), 'Pesos', False, 0.25, 'flag_pilipinas.png'),
    56: ('Eesti', _('Estonia'), 'Krooni', False, 0.5, 'flag_eesti.png'),
    57: ('Srbija i Crna Gora', _('Serbia and Montenegro'), 'Dinar', False, 1, 'flag_serbia.png'),
    58: ('Hrvatska', _('Croatia'), 'Kuna', False, 1, 'flag_hrvatska.png'),
    59: ('Hong Kong', _('Hong Kong'), 'HKD', False, 1, 'flag_hong_kong.png'),
    60: ('Taiwan', _('Taiwan'), '$', True, 10, 'flag_taiwan.png'),
    61: ('Wales', _('Wales'), '', True, 15, 'flag_wales.png'),
    62: ('Bulgaria', _('Bulgaria'), 'Lev', False, 5, 'flag_bulgaria.png'),
    63: ('Israel', _('Israel'), 'NIS', False, 2, 'flag_israel.png'),
    64: ('Slovenija', _('Slovenia'), 'Euro', False, 10, 'flag_slovenija.png'),
    66: ('Lietuva', _('Lithuania'), 'Lt', False, 2.5, 'flag_lietuva.png'),
    67: ('Slovakia', _('Slovakia'), 'Koruna', False, 0.2, 'flag_slovakia.png'),
    68: ('Ukraina', _('Ukraine'), 'Hryvnia', False, 2, 'flag_ukraina.png'),
    69: ('Bosnia', _('Bosnia'), 'Marka', False, 5, 'flag_bosnia.png'),
    70: ('Vietnam', _('Vietnam'), 'Dong', False, 1, 'flag_vietnam.png'),
    71: ('Pakistan', _('Pakistan'), 'Rupee', False, 0.2, 'flag_pakistan.png'),
    72: ('Paraguay', _('Paraguay'), 'PYG', False, 0.002, 'flag_paraguay.png'),
    73: ('Ecuador', _('Ecuador'), '$', True, 10, 'flag_ecuador.png'),
    74: ('Bolivia', _('Bolivia'), 'BOB', False, 1, 'flag_bolivia.png'),
    75: ('Nigeria', _('Nigeria'), 'kNaria', False, 0.1, 'flag_nigeria.png'),
    76: ('Froya', _('Faroe Islands'), 'Kr', False, 1, 'flag_foroya.png'),
    77: ('Al Maghrib', _('Marocco'), 'Dirhams', False, 1, 'flag_al_maghrib.png')
    }

