# -*- coding: iso-8859-1 -*-

# Mattricks, a free helper program for hattricks players.
# Copyright (C) 2003 Mattricks Team
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import urllib
import os.path
import re
import string
import sys
import time

import Version
import HRFData
import XMLData

FETCH_ERROR_STRANGE_RESPONSE = 1
FETCH_ERROR_LOGIN_ERROR = 2
FETCH_ERROR_PLAYING_MATCH = 3
FETCH_ERROR_ERRONEOUS_DATA = 4
FETCH_ERROR_COULDNT_GET_COOKIE = 5
FETCH_ERROR_COULDNT_CONNECT = 6

class FetchError(Exception):
    def __init__(self, s, type = -1, extra_info = ""):
        self.type = type
        self.extra_info = extra_info
        self.s = s

    def __str__(self):
        return str(self.s)

class MattricksURLopener(urllib.FancyURLopener):
    def __init__(self, *args):
        self.version = "Mattricks/" + Version.version
        urllib.FancyURLopener.__init__(self, *args)

urllib._urlopener = MattricksURLopener()

def make_hrf_filename(path, always_download, overwrite_old):
    def make_real_path(path, amount_numbers):
        filename = string.join(["%04d", "-%02d", "-%02d", \
                                "_%02d", "-%02d", "-%02d"][:amount_numbers], "") % \
                                time.localtime(time.time())[:amount_numbers] + ".hrf"
        return os.path.realpath(os.path.join(os.path.expanduser(path), filename))

    filename = make_real_path(path, 3)
    if os.path.exists(filename):
        if not always_download:
            return
        elif overwrite_old:
            return filename
        else:
            filename = make_real_path(path, 6)
    return filename

class Connection:
    def __init__(self):
        self.current_user = None
        self.current_server = None
        self.cookie = None

    def login(self, loginname, password, server = "195.149.159.156"):
        if self.cookie == None or \
           self.current_user != loginname or \
           self.current_server != server:

            try:
                u = urllib.urlopen("http://" + server + "/Common/default.asp", \
                                   urllib.urlencode([("loginname", loginname), \
                                                     ("password", password), \
                                                     ("action", "login"), \
                                                     ("submit", "Log on")]))
            except IOError, e:
                raise FetchError(_("Unable to connect to the server."),
                                 FETCH_ERROR_COULDNT_CONNECT)

            try:
                cookie = u.info()['set-cookie']
                cookie = cookie[:string.find(cookie, ";")]
            except:
                raise FetchError(_("Unable to get cookie."),
                                 FETCH_ERROR_COULDNT_GET_COOKIE)

            regexp = re.compile("loginError=(Yes|)&", re.IGNORECASE)
            pwdata = u.read()
            result = regexp.search(pwdata)
            if not result:
                raise FetchError(_("Strange response in fetch."),
                                 FETCH_ERROR_STRANGE_RESPONSE,
                                 pwdata)
            if len(result.group(1)) > 0:
                raise FetchError(_("Failed to login, please try again!"),
                                 FETCH_ERROR_LOGIN_ERROR)

            self.current_user = loginname
            self.current_server = server
            self.cookie = cookie

    def fetch_hrf(self, loginname, password, path = "",
                  dlg = None, filename = None,
                  always_download = True, overwrite_old = False,
                  server = "195.149.159.156"):

        if filename == None:
            filename = make_hrf_filename(path, always_download, overwrite_old)

        if filename == None:
            return None

        self.login(loginname, password, server)

        if dlg != None:
            dlg.Update(2)

        o = MattricksURLopener()

        if dlg != None:
            dlg.Update(5, _("Downloading hrf-file ..."))

        o.addheader("Cookie", self.cookie)
        try:
            u = o.open("http://" + server +"/Common/hrf.asp")
            content = u.read()
        except IOError, e:
            raise FetchError(_("Unable to connect to the server."),
                             FETCH_ERROR_COULDNT_CONNECT)

        m = HRFData.HTDir.re_date.search(content)
        if m:
            open(filename, 'w').write(content)
        else:
            m = re.compile("playingMatch=true").search(content)
            if m:
                raise FetchError(_("Team is currently playing match."),
                                 FETCH_ERROR_PLAYING_MATCH)
            else:
                raise FetchError(_("The retrieved data is errouneous."),
                                 FETCH_ERROR_ERRONEOUS_DATA)

        if dlg != None:
            dlg.Update(9, _("Updating tables ..."))

        return filename

    def fetch_fixtures_xml(self, loginname, password, path = "",
                           dlg = None, filename = None,
                           leagueids = [], seasons = [],
                           server = "195.149.159.156"):
        if len(leagueids) == 0:
            leagueids = [None]
        if len(seasons) == 0:
            seasons = [None]

        filenames = []
        for leagueid in leagueids:
            for season in seasons:
                filenames.append(self.__internal_fetch_fixtures_xml(loginname,
                                                                    password,
                                                                    path,
                                                                    dlg,
                                                                    filename,
                                                                    leagueid,
                                                                    season,
                                                                    server))
        return filenames

    def __internal_fetch_fixtures_xml(self, loginname, password, path = "",
                                      dlg = None, filename = None,
                                      leagueid = None, season = None,
                                      server = "195.149.159.156"):

        self.login(loginname, password, server)

        if dlg != None:
            dlg.Update(2)

        o = MattricksURLopener()

        if dlg != None:
            dlg.Update(5, _("Downloading fixtures files ..."))

        o.addheader("Cookie", self.cookie)
        post = [("outputType", "XML")]
        if leagueid != None:
            post += [("leagueLevelUnitId", str(leagueid))]
        if season != None:
            post += [("season", str(season))]

        try:
            u = o.open("http://" + server +"/Common/leagueFixtures.asp",
                       urllib.urlencode(post))
            content = u.read()
        except IOError, e:
            raise FetchError(_("Unable to connect to the server."),
                             FETCH_ERROR_COULDNT_CONNECT)

        if filename == None:
            fixtures = XMLData.parse_string_fixtures(content)
            leagueid = fixtures.league_id
            season = fixtures.season

            filename = "fixtures-%d-s%d.xml" % (leagueid, season)

        filename = os.path.realpath(os.path.join(os.path.expanduser(path), filename))
        open(filename, 'w').write(content)

        if dlg != None:
            dlg.Update(9, _("Updating tables ..."))

        return filename

conn = Connection()
