# -*- coding: iso-8859-1 -*-

# Mattricks, a free helper program for hattricks players.
# Copyright (C) 2003 Mattricks Team
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import XMLData

from Common import *
from Commonwx import *
from wxPython.wx import *
from wxPython.lib.scrolledpanel import wxScrolledPanel

class LeaguePage(wxPanel):
    ID_LEAGUE = 523
    ID_SEASON = 524
    ID_TYPE = 525

    def __init__(self, parent, ID):
        wxPanel.__init__(self, parent, ID)

        sizer = wxBoxSizer(wxVERTICAL)
        hsizer = wxBoxSizer(wxHORIZONTAL)

        stext = wxStaticText(self, -1, _("League") + ":")
        hsizer.Add(stext, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 5)

        self.league_choice = wxChoice(self, self.ID_LEAGUE,
                                      choices = [str(x) for x in \
                                                 XMLData.xmldirs.fixtures_list.keys()])
        hsizer.Add(self.league_choice, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 5)

        stext = wxStaticText(self, -1, _("Season") + ":")
        hsizer.Add(stext, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 5)

        current_league = self.__get_current_league()
        if current_league:
            seasons = XMLData.xmldirs.fixtures_list[current_league].keys()
            seasons.reverse()
        else:
            seasons = []
        self.season_choice = wxChoice(self, self.ID_SEASON,
                                      choices = [str(x) for x in seasons])
        hsizer.Add(self.season_choice, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 5)


        stext = wxStaticText(self, -1, _("Matches") + ":")
        hsizer.Add(stext, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 5)

        type_choices=[_("All"), _("Home"), _("Away")]

        self.type_choice = wxChoice(self, self.ID_TYPE,
                                      choices = type_choices)
        hsizer.Add(self.type_choice, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 5)

        sizer.AddSizer(hsizer, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 0)

        hsizer=wxBoxSizer(wxHORIZONTAL)
        seriestext = wxStaticText(self,-1, _("League") + ": ", style=wxALIGN_LEFT)
        SetTextFace(seriestext, FACE_BOLD|FACE_BIG)
        hsizer.Add(seriestext, 0, wxEXPAND | wxALL, 5)
        self.league_name = wxStaticText(self,-1, "                      ", style=wxALIGN_LEFT)
        SetTextFace(self.league_name, FACE_BOLD|FACE_BIG)
        hsizer.Add(self.league_name, 0, wxEXPAND | wxALL, 5)
        sizer.AddSizer(hsizer, 0, wxEXPAND | wxALL, 5)

        fgsizer = wxFlexGridSizer(cols=9, vgap=0, hgap=0)
        fgsizer.AddGrowableCol(1)

        aligns = [wxALIGN_RIGHT, wxALIGN_LEFT, wxALIGN_CENTRE] + \
                 [wxALIGN_RIGHT]*4 + [wxALIGN_CENTRE, wxALIGN_RIGHT]
        sizes = [0, 1] + [0]*7
        i = 0
        for h in [_("Pos"), _("Name"), _("Id"), _("Pl"), _("W"), _("D"),
                  _("L"), _("For - Against"), _("Po")]:
            stext = wxStaticText(self, -1, h, style = aligns[i])
            SetTextBold(stext)
            fgsizer.Add(stext, sizes[i], wxEXPAND | wxADJUST_MINSIZE | wxALL, 5)
            i += 1

        self.table_texts = {}
        row = 0
        for rc in ["#C8F8C8"] + ["#F0F0F0", "#E8E8E8"]*3 + ["#F8C8C8"]:
            col = 0
            for align, size in zip(aligns, sizes):
                gpanel = SimpleColouredPanel(self, -1, rc)
                stext = wxStaticText(gpanel, -1, "",
                                     style = align | wxST_NO_AUTORESIZE)
                gpanel.AddChild(stext, 1, wxADJUST_MINSIZE | align | wxALL, 3)
                fgsizer.Add(gpanel, size, wxEXPAND | wxADJUST_MINSIZE | wxALL, 0)
                self.table_texts[(row, col)] = stext
                col += 1
            row += 1

        sizer.AddSizer(fgsizer, 0, wxEXPAND |wxALL, 5)

        self.scrolled_panel = wxScrolledPanel(self, -1)
        scroll_sizer = wxBoxSizer(wxVERTICAL)
        self.scrolled_panel.SetSizer(scroll_sizer, True)
        self.scrolled_panel.SetAutoLayout(True)
        scroll_sizer.Fit(self.scrolled_panel)
        sizer.Add(self.scrolled_panel, 1, wxEXPAND | wxALL, 5)
        self.fixture_panel = None

        self.SetSizer(sizer)
        self.SetAutoLayout(True)
        sizer.Fit(self)

        self.Update()

        EVT_CHOICE(self, self.ID_LEAGUE, self.OnLeagueChange)
        EVT_CHOICE(self, self.ID_SEASON, self.OnSeasonChange)
        EVT_CHOICE(self, self.ID_TYPE, self.OnTypeChange)

    def OnLeagueChange(self, event):
        self.__update_seasons()
        self.Update()

    def OnSeasonChange(self, event):
        self.Update()

    def OnTypeChange(self, event):
        self.__change_table()

    def ChangeHRF(self, hrffile):
        pass

    def UpdateXMLs(self, xmlfiles):
        self.__update_leagues()
        self.__update_seasons()
        self.Update()

    def Update(self):
        current_league = self.__get_current_league()
        current_season = self.__get_current_season()

        fn = None
        if current_league and current_season:
            fn = XMLData.xmldirs.get_fixture(current_league, current_season)
        if fn:
            self.fixtures = XMLData.xmlstorage.get(fn)

            league_name = self.fixtures.get_league_name()
            self.league_name.SetLabel(league_name)
        else:
            self.fixtures = None

        self.__change_table()
        self.__update_fixtures()

        self.GetSizer().Layout()
        self.Refresh()

    def __update_leagues(self):
        current_league = self.__get_current_league()
        leagues = XMLData.xmldirs.fixtures_list.keys()
        self.league_choice.Clear()
        [self.league_choice.Append(str(x)) for x in leagues]
        if current_league in leagues:
            self.league_choice.SetStringSelection(str(current_league))
        elif len(leagues) > 0:
            self.league_choice.SetStringSelection(str(leagues[0]))

    def __update_seasons(self):
        current_league = self.__get_current_league()
        if current_league:
            seasons = XMLData.xmldirs.fixtures_list[current_league].keys()
            seasons.reverse()
        else:
            seasons = []
        current_season = self.__get_current_season()
        self.season_choice.Clear()
        [self.season_choice.Append(str(x)) for x in seasons]
        if current_season in seasons:
            self.season_choice.SetStringSelection(str(current_season))
        elif len(seasons) > 0:
            self.season_choice.SetStringSelection(str(seasons[0]))
        if self.type_choice.GetSelection() < 0:
            self.type_choice.SetSelection(0)

    def __change_table(self):
        if not self.fixtures:
            for stext in self.table_texts.values():
                stext.SetLabel("")
            return

        current_type = self.__get_current_type()

        (allteams, hteams, ateams) = self.fixtures.calc_table()

        if current_type == 0:
            teams = allteams
        elif current_type == 1:
            teams = hteams
        elif current_type == 2:
            teams = ateams
        else:
            return

        row = 0
        for pl, w, d, l, f, a, po, n, tid in teams:
            self.table_texts[(row, 0)].SetLabel("    " + str(row + 1))
            self.table_texts[(row, 1)].SetLabel(n)
            self.table_texts[(row, 2)].SetLabel("   " + str(tid) + "   ")
            self.table_texts[(row, 3)].SetLabel("    " + str(pl))
            self.table_texts[(row, 4)].SetLabel("    " + str(w))
            self.table_texts[(row, 5)].SetLabel("    " + str(d))
            self.table_texts[(row, 6)].SetLabel("    " + str(l))
            self.table_texts[(row, 7)].SetLabel("  %d - %d  " % (f, a))
            self.table_texts[(row, 8)].SetLabel("    " + str(po))
            row += 1

    def __update_fixtures(self):
        scroll_sizer = self.scrolled_panel.GetSizer()
        if self.fixture_panel != None:
            self.fixture_panel.Destroy()
            self.fixture_panel = None

        if not self.fixtures:
            return

        def goals2str(g):
            if g < 0:
                return "x"
            return str(g)

        self.fixture_panel = wxPanel(self.scrolled_panel, -1)
        sizer = wxBoxSizer(wxVERTICAL)

        matches = self.fixtures.matches
        eligible_rounds = matches.keys()
        eligible_rounds.sort()
        rcs = ["#F0F0F0", "#E8E8E8"]
        for r in eligible_rounds:
            stext = wxStaticText(self.fixture_panel, -1, _("Round %d") % r + ":")
            SetTextBold(stext)
            sizer.Add(stext, 0, wxEXPAND | wxALL, 5)

            fgsizer = wxFlexGridSizer(cols=6, vgap=0, hgap=0)
            for i in [0,2]:
                fgsizer.AddGrowableCol(i)

            rc = 0
            for m_id, vals in matches[r].items():
                hteam = vals["hometeamname"]
                ateam = vals["awayteamname"]

                hgoals = vals["homegoals"]
                agoals = vals["awaygoals"]


                for t in [hteam, "-", ateam, goals2str(hgoals), "-", goals2str(agoals)]:
                    if t in [hteam, ateam]:
                        size = 1
                    else:
                        size = 0

                    stext = wxStaticText(self.fixture_panel, -1, t)
                    fgsizer.Add(stext, size, wxEXPAND | wxADJUST_MINSIZE | wxLEFT | wxRIGHT, 5)
                rc = (rc + 1) % 2
            sizer.AddSizer(fgsizer, 0, wxEXPAND | wxALL, 5)

        self.fixture_panel.SetSizer(sizer, True)
        self.fixture_panel.SetAutoLayout(True)
        sizer.Fit(self.fixture_panel)

        scroll_sizer.Add(self.fixture_panel, 1, wxEXPAND | wxALL, 0)
        self.scrolled_panel.Layout()
        self.scrolled_panel.SetupScrolling()

    def __get_current_league(self):
        current_league = self.league_choice.GetStringSelection()
        if not current_league:
            return None
        return int(current_league)

    def __get_current_season(self):
        current_season = self.season_choice.GetStringSelection()
        if not current_season:
            return None
        return int(current_season)

    def __get_current_type(self):
        current_type = self.type_choice.GetSelection()
        return current_type
