# -*- coding: iso-8859-1 -*-

# Mattricks, a free helper program for hattricks players.
# Copyright (C) 2003 Mattricks Team
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import os
import os.path
import time
import sys

from Config import config
import Errorwx
import HRFData
import XMLData
import AboutPage
import Playerlist
import ComparisonPage
import Fetchdialog
import Fetch
import EconomyPage
import LeaguePage
import LineupPage
import MatchPrediction
import SummaryPage
import JuniorSpy
import TeamSelectorPage
import Configdialog

from Images import Images

from wxPython.wx import *
from Common import *
from Commonwx import *

class MainFrame(wxFrame):
    ID_FETCH = 101
    ID_REFETCH = 102
    ID_EXIT  = 103
    ID_CONFIG = 104
    ID_OPEN = 105

    def __init__(self, parent, ID, title, filename):
        wxFrame.__init__(self, parent, ID, title)

        if filename != None:
            config.set("Fetch", "save directory", os.path.dirname(filename))

        self.default_pass = ""
        self.default_user = ""

        sizer = wxBoxSizer(wxVERTICAL)

        hsizer = wxBoxSizer(wxHORIZONTAL)

        buttons = [(MainFrame.ID_FETCH, _("Download data")),
                   (MainFrame.ID_REFETCH, _("Redownload data")),
                   (MainFrame.ID_CONFIG, _("Preferences")),
                   (MainFrame.ID_OPEN, _("Open data file")),
                   (MainFrame.ID_EXIT, _("Exit"))]
        for id, info in buttons:
            button = wxButton(self, id, info)
            hsizer.Add(button, 1, wxEXPAND | wxALIGN_CENTRE | wxALL, 0)

        sizer.AddSizer(hsizer, 0, wxEXPAND | wxBOTTOM, 0)

        notebook = wxNotebook(self, -1)
        nbsizer = wxNotebookSizer(notebook)

        the_pages = [
            ("about", "Mattricks", AboutPage.AboutPage(notebook, -1)),
            ("summary", _("Summary"), SummaryPage.SummaryPage(notebook, -1, filename)),
            ("player", _("Player lists"), Playerlist.PlayerPage(notebook, -1, filename)),
            ("comparison", _("Comparisons"), ComparisonPage.ComparisonPage(notebook, -1)),
            ("economy", _("Economy"), EconomyPage.EconomyPage(notebook, -1, filename)),
            ("table", _("League table"), LeaguePage.LeaguePage(notebook, -1)),
            ("lineup", _("Lineup"), LineupPage.LineupPage(notebook, -1, filename)),
            ("lineupselect", _("Lineup selection"),
             TeamSelectorPage.TeamSelectorPage(notebook, -1, filename)),
            ("prediction", _("Game prediction"), MatchPrediction.MatchPrediction(notebook, -1))
            ]
        self.pages = {}
        for name, descr, page in the_pages:
            notebook.AddPage(page, descr)
            self.pages[name] = page

        sizer.AddSizer(nbsizer, 1, wxEXPAND | wxALL, 0)

        self.SetSizer(sizer)
        self.SetAutoLayout(True)
        sizer.Fit(self)

        EVT_BUTTON(self, MainFrame.ID_OPEN, self.OnOpen)
        EVT_BUTTON(self, MainFrame.ID_FETCH, self.OnFetch)
        EVT_BUTTON(self, MainFrame.ID_CONFIG, self.OnConfig)
        EVT_BUTTON(self, MainFrame.ID_REFETCH, self.OnRefetch)
        EVT_BUTTON(self, MainFrame.ID_EXIT,  self.OnExit)

        icons = wxIconBundle()
        for iconsize in [16, 32, 48, 64]:
            iconbmp = Images.get_bitmap_from_file("icon-%dx%d.png" % (iconsize, iconsize))
            icon = wxEmptyIcon()
            icon.CopyFromBitmap(iconbmp)
            icons.AddIcon(icon)
        self.SetIcons(icons)

    def AfterInit(self):
        self.default_dir = config.get("Fetch", "save directory")
        self.default_jspy = config.get("Fetch", "junior spy")
        self.default_adownload = config.get("Fetch", "always download")
        self.default_override = config.get("Fetch", "override old hrf")
        self.default_server = config.get("Fetch", "ip number")
        if config.get("Fetch", "download at startup"):
            self.__do_fetch(True,
                            self.default_dir, self.default_user, self.default_pass,
                            self.default_jspy, self.default_adownload, self.default_override,
                            self.default_server)
        return True

    def OnOpen(self, event):
        wildcard = "HRF Files (*.hrf)|*.hrf|" \
                   "All files (*.*)|*.*"

        dlg = wxFileDialog(self, _("Choose file with hattrick data."), wildcard = wildcard,
                           style = wxOPEN, defaultDir = self.default_dir)
        if dlg.ShowModal() == wxID_OK:
            self.__change_hrf(dlg.GetPath())
        dlg.Destroy()

    def OnFetch(self, event):
        self.default_dir = config.get("Fetch", "save directory")
        self.default_jspy = config.get("Fetch", "junior spy")
        self.default_adownload = config.get("Fetch", "always download")
        self.default_override = config.get("Fetch", "override old hrf")
        self.default_server = config.get("Fetch", "ip number")
        self.__do_fetch(True,
                        self.default_dir, self.default_user, self.default_pass,
                        self.default_jspy, self.default_adownload, self.default_override,
                        self.default_server)

    def OnRefetch(self, event):
        self.default_dir = config.get("Fetch", "save directory")
        self.default_jspy = config.get("Fetch", "junior spy")
        self.default_adownload = config.get("Fetch", "always download")
        self.default_override = config.get("Fetch", "override old hrf")
        self.default_server = config.get("Fetch", "ip number")
        self.__do_fetch(False,
                        self.default_dir, self.default_user, self.default_pass,
                        self.default_jspy, self.default_adownload, self.default_override,
                        self.default_server)

    def OnExit(self, event):
        self.Close(True)

    def OnConfig(self, event):
        if not Configdialog.ConfigDialog.conf_dialog_running:
            dlg = Configdialog.ConfigDialog(self, -1)
            dlg.Show()

    def __change_hrf(self, hrffile):
        hrfdir = os.path.dirname(hrffile)
        HRFData.htdirs.add_from_filename(hrffile)
        XMLData.xmldirs.add_dirs(hrfdir)
        for name, page in self.pages.items():
            page.ChangeHRF(hrffile)

    def __change_xmls(self, xmlfiles):
        self.pages["table"].UpdateXMLs(xmlfiles)

    def __do_fetch(self, use_dialog,
                   path, loginname, password, juniorspy,
                   always_download, overwrite_old, server):

        exit = False
        hrffile = None
        xmlfiles = []
        if use_dialog:
            dlg = Fetchdialog.FetchDialog(self, _("Download data"),
                                          defaultDir = self.default_dir,
                                          defaultPass = self.default_pass,
                                          defaultUser = self.default_user,
                                          defaultJSpy = self.default_jspy,
                                          defaultADownload = self.default_adownload,
                                          defaultOverride = self.default_override)
            while not exit:
                res = dlg.ShowModal()
                if res == wxID_OK:
                    args = dlg.GetResult() + (self.default_server,)
                    juniorspy = args[3]
                    (exit, hrffile, xmlfiles) = self.__do_fetch_internal(*args)
                else:
                    exit = True
            dlg.Destroy()
        else:
            (exit, hrffile, xmlfiles) = self.__do_fetch_internal(self.default_dir,
                                                                 self.default_user,
                                                                 self.default_pass,
                                                                 self.default_jspy,
                                                                 self.default_adownload,
                                                                 self.default_override,
                                                                 False, None, None,
                                                                 self.default_server)

        if hrffile != None:
            if juniorspy == True:
                psdlg=JuniorSpy.JuniorSpySelect(self,HRFData.hrfstorage[hrffile])
                psdlg.ShowModal()
            self.__change_hrf(hrffile)

        if len(xmlfiles) > 0:
            self.__change_xmls(xmlfiles)

    def __do_fetch_internal(self, path, loginname, password, juniorspy,
                            always_download, overwrite_old,
                            dl_fixtures, leagueid, season, server):

        hrffile = None
        xmlfiles = []
        exit = False
        err_message = None
        pddlg = None
        if len(loginname) == 0 or len(password) == 0:
            err_message = _("You have to supply both username and password")
        else:
            pddlg = wxProgressDialog(_("Fetching hrf file ..."),
                                     _("Logging in ..."),
                                     10,
                                     self,
                                     wxPD_APP_MODAL)

            self.default_user = loginname
            self.default_pass = password
            try:
                result = Fetch.conn.fetch_hrf(loginname, password, path, pddlg, None,
                                              always_download, overwrite_old, server)
                if dl_fixtures:
                    xmlfiles = Fetch.conn.fetch_fixtures_xml(loginname, password, path,
                                                             pddlg, None,
                                                             [leagueid], [season], server)
                hrffile = result
                exit = True
            except Fetch.FetchError, e:
                err_message = str(e)
                if e.type != Fetch.FETCH_ERROR_LOGIN_ERROR:
                    exit = True

        if pddlg != None:
            pddlg.Destroy()

        if err_message != None:
            mdlg = wxMessageDialog(self, err_message,
                                  _("Error"), wxOK | wxICON_ERROR)
            mdlg.ShowModal()
            mdlg.Destroy()

        return (exit, hrffile, xmlfiles)

class Main(wxApp):
    ID_FRAME = 201
    def __init__(self, filename = None):
        self.initial_file = filename
        wxApp.__init__(self)

    def OnInit(self):
        frame = MainFrame(NULL, Main.ID_FRAME, "Mattricks", self.initial_file)
        frame.Show(true)

        Errorwx.error.init_errorwx(frame)

        self.SetTopWindow(frame)
        del self.initial_file

        frame.AfterInit()
        return true

def main(*hrfs):
    filename = None
    if len(hrfs) == 0:
        hrfs = config.get("General", "hrf directories")
    for hrf in hrfs:
        hrf = os.path.realpath(os.path.expanduser(hrf))
        hrfdir = os.path.dirname(hrf)
        if os.path.isdir(hrf):
            HRFData.htdirs.add_dirs(hrf)
            XMLData.xmldirs.add_dirs(hrf)
        else:
            HRFData.htdirs.add_from_filename(hrf)
            XMLData.xmldirs.add_dirs(hrfdir)
            filename = hrf

    if filename == None:
        filename = HRFData.htdirs.get_from_time(time.time())

    app = Main(filename)
    app.MainLoop()
