# -*- coding: iso-8859-1 -*-

# Mattricks, a free helper program for hattricks players.
# Copyright (C) 2003 Mattricks Team
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import DataInfo
import HRFData
import Terms

from wxPython.wx import *
from Common import *
from Commonwx import *
from Images import Images, create_star_image



class PlayerDialog(wxDialog):

    def __init__(self, parent, htdata, player_id):

        pos = wxDefaultPosition
        size = wxDefaultSize,
        style = wxDEFAULT_DIALOG_STYLE

        wxDialog.__init__(self, parent, -1, htdata.get_player(player_id,True).name, pos, wxSize(500, 400), style, htdata.get_player(player_id,True).name)

        totsizer=wxBoxSizer(wxVERTICAL)

        namesizer = wxBoxSizer(wxHORIZONTAL)

        nametext=wxStaticText(self,-1,htdata.get_player(player_id,True).name + " (" + str(player_id) + ")")
        SetTextFace(nametext, FACE_BOLD | FACE_BIG)
        namesizer.Add(nametext, 0, wxALL,5)

        yellows=htdata.get_player(player_id).warnings
        if yellows > 0:
            if yellows == 3:
                img = Images.get_bitmap_from_file("redcard.png")
            elif yellows == 2:
                img =  Images.get_bitmap_from_file("2yellowcards.png")
            else:
                img =  Images.get_bitmap_from_file("yellowcard.png")
            namesizer.Add(wxStaticBitmap(self,-1,img),0,wxALL|wxALIGN_CENTER_VERTICAL ,2)

        injury=htdata.get_player(player_id).ska
        if injury == 0:
            namesizer.Add(wxStaticText(self,-1,_("Bruised")))
        elif injury > 0:
            iimg =  Images.get_bitmap_from_file("injury.png")
            namesizer.Add(wxStaticBitmap(self,-1,iimg),0,wxALL|wxALIGN_CENTER_VERTICAL ,2)
            namesizer.Add(wxStaticText(self,-1,str(injury)),0,wxALL|wxALIGN_CENTER_VERTICAL ,1)

        totsizer.AddSizer(namesizer, 0, wxALL, 5)

        notebook = wxNotebook(self, -1)
        nbsizer = wxNotebookSizer(notebook)

        notebook.AddPage(PlayerTab(notebook, htdata, player_id), _("Information"))
        notebook.AddPage(EvalTab(notebook, htdata, player_id), _("Evaluation"))

        totsizer.AddSizer(nbsizer, 1, wxEXPAND | wxALL, 0)

        # Ok / Cancel buttons

        button = wxButton(self, wxID_OK, _("Ok"))
        button.SetDefault()

        totsizer.Add(button, 0, wxALIGN_RIGHT | wxALL, 10)

        self.SetSizer(totsizer)
        self.SetAutoLayout(True)
        totsizer.Fit(self)

class PlayerTab(wxPanel):

    def __init__(self, parent, htdata, player_id):

        abilities=[
            'for',
            'rating',
            'CountryID',
            'speciality']

        economy=[
            'mkt',
            'sal']

        personality=[
            'ald',
            'rut',
            'gentleness',
            'Aggressiveness',
            'honesty',
            'led']

        playerabilities=[
            'uth',
            'mlv',
            'spe',
            'fra',
            'ytt',
            'bac',
            'mal',
            'fas']

        goals = [
            'gev',
            'hat',
            'gtl',
            'gtc',
            'gtt']

        wxPanel.__init__(self, parent, -1)

        totsizer=wxBoxSizer(wxVERTICAL)
        sizer = wxBoxSizer(wxVERTICAL)

        if htdata != None:
            fgs=wxFlexGridSizer(cols=2, vgap=5, hgap=10)
            for text in abilities:
                if text == None:
                    fgs.Add(15,15)
                    fgs.Add(15,15)
                else:
                    value = getattr(htdata.get_player(player_id),text)
                    if value > 0:
                        attributetext=wxStaticText(self,-1,DataInfo.known_player_data_info[text][1])
                        SetTextFace(attributetext, FACE_BOLD)
                        fgs.Add(attributetext)
                        picname=None
                        if text=='CountryID':
                            CID=Terms.country[value]
                            picname=Images.get_bitmap_from_file(DataInfo.country_info[CID][5])
                        elif text=='rating':
                            picname=create_star_image(value)
                        if picname == None:
                            fgs.Add(wxStaticText(self,-1,getattr(htdata.get_player(player_id,True),text)))
                        else:
                            picsizer=wxBoxSizer(wxHORIZONTAL)
                            picsizer.Add(wxStaticBitmap(self,-1,picname))
                            picsizer.Add(wxStaticText(self,-1,"  " + getattr(htdata.get_player(player_id,True),text)))
                            fgs.AddSizer(picsizer)
            sizer.AddSizer(fgs, 0, wxALL | wxEXPAND, 5)

        economysizer_box=wxStaticBox(self,-1, _("Economy"))
        economysizer = wxStaticBoxSizer(economysizer_box, wxHORIZONTAL)

        if htdata != None:
            fgs=wxFlexGridSizer(cols=4, vgap=5, hgap=10)
            fgs.AddGrowableCol(0)
            fgs.AddGrowableCol(1)
            fgs.AddGrowableCol(2)
            fgs.AddGrowableCol(3)
            for text in economy:
                attributetext=wxStaticText(self,-1,DataInfo.known_player_data_info[text][1])
                SetTextFace(attributetext, FACE_BOLD)
                fgs.Add(attributetext)
                fgs.Add(wxStaticText(self,-1,getattr(htdata.get_player(player_id,True),text)))

            economysizer.AddSizer(fgs, 1, wxALL |wxEXPAND, 5)

        sizer.AddSizer(economysizer, 0, wxALIGN_LEFT | wxALL | wxEXPAND, 5)

        personalitysizer_box=wxStaticBox(self,-1, _("Personality"))
        personalitysizer = wxStaticBoxSizer(personalitysizer_box, wxHORIZONTAL)

        if htdata != None:
            fgs=wxFlexGridSizer(cols=4, vgap=5, hgap=10)
            fgs.AddGrowableCol(0)
            fgs.AddGrowableCol(1)
            fgs.AddGrowableCol(2)
            fgs.AddGrowableCol(3)
            for text in personality:
                attributetext=wxStaticText(self,-1,DataInfo.known_player_data_info[text][1])
                SetTextFace(attributetext, FACE_BOLD)
                fgs.Add(attributetext)
                fgs.Add(wxStaticText(self,-1,getattr(htdata.get_player(player_id,True),text)))

            personalitysizer.AddSizer(fgs, 1, wxALL |wxEXPAND, 5)

        sizer.AddSizer(personalitysizer, 0, wxALIGN_LEFT | wxALL | wxEXPAND, 5)

        playersizer_box=wxStaticBox(self,-1, _("Abilities"))
        playersizer = wxStaticBoxSizer(playersizer_box, wxHORIZONTAL)

        if htdata != None:
            fgs=wxFlexGridSizer(cols=4, vgap=5, hgap=10)
            fgs.AddGrowableCol(0)
            fgs.AddGrowableCol(1)
            fgs.AddGrowableCol(2)
            fgs.AddGrowableCol(3)
            for text in playerabilities:
                attributetext=wxStaticText(self,-1,DataInfo.known_player_data_info[text][1])
                SetTextFace(attributetext, FACE_BOLD)
                fgs.Add(attributetext)
                fgs.Add(wxStaticText(self,-1,getattr(htdata.get_player(player_id,True),text)))

            playersizer.AddSizer(fgs, 1, wxALL |wxEXPAND, 5)

        sizer.AddSizer(playersizer, 0, wxALIGN_LEFT | wxALL | wxEXPAND, 5)

        goalsizer_box=wxStaticBox(self,-1, _("Number of goals"))
        goalsizer = wxStaticBoxSizer(goalsizer_box, wxVERTICAL)

        if htdata != None:
            fgs=wxFlexGridSizer(cols=2, vgap=5, hgap=10)
            for text in goals:
                attributetext=wxStaticText(self,-1,DataInfo.known_player_data_info[text][1])
                SetTextFace(attributetext, FACE_BOLD)
                fgs.Add(attributetext)
                fgs.Add(wxStaticText(self,-1,getattr(htdata.get_player(player_id,True),text)))

            goalsizer.AddSizer(fgs, 0, wxALIGN_CENTER | wxALL, 5)

        hsizer=wxBoxSizer(wxHORIZONTAL)
        hsizer.AddSizer(sizer, 0, wxALIGN_LEFT | wxALIGN_BOTTOM| wxALL, 5)
        hsizer.AddSizer(goalsizer, 0, wxALIGN_BOTTOM | wxALL, 5)

        totsizer.AddSizer(hsizer, 0, wxALL, 5)
        # Ok / Cancel buttons

        self.SetSizer(totsizer)
        self.SetAutoLayout(True)
        totsizer.Fit(self)

class EvalTab(wxPanel):

    def __init__(self, parent, htdata, player_id):

        positions=[[None, [_("Goalkeeper"), ["ts_goalie"],0], None],
                   [[_("Wingback"),
                     ["ts_wingback", "ts_wingback_offensive",
                     "ts_wingback_defensive","ts_wingback_towards_the_middle"],1],

                   [_("Central defender"),
                    ["ts_centraldefender",
                    "ts_centraldefender_offensive","ts_centraldefender_towards_the_wing"],1]],

                   [[_("Winger"),
                     ["ts_winger", "ts_winger_offensive",
                     "ts_winger_defensive","ts_winger_towards_the_middle"],1],

                   [_("Midfielder"),
                    ["ts_innermid", "ts_innermid_offensive",
                    "ts_innermid_defensive","ts_innermid_towards_the_wing"],1]],

                   [None, [_("Forward"), ["ts_forward", "ts_forward_defensive"],0], None]]


        wxPanel.__init__(self, parent, -1)

        totsizer=wxBoxSizer(wxVERTICAL)

        if htdata != None:
            for p in positions:
                psizer=wxBoxSizer(wxHORIZONTAL)
                for pos in p:
                    if pos == None:
                        psizer.Add(1,1,1)
                    else:
                        box=wxStaticBox(self,-1, pos[0])
                        boxsizer= wxStaticBoxSizer(box, wxHORIZONTAL)
                        fgs=wxFlexGridSizer(cols=2, vgap=5, hgap=10)
                        fgs.AddGrowableCol(0)
                        for text in pos[1]:
                            attributetext=wxStaticText(self,-1,DataInfo.known_player_data_info[text][1])
                            SetTextFace(attributetext, FACE_BOLD)
                            fgs.Add(attributetext)
                            fgs.Add(wxStaticText(self,-1,getattr(htdata.get_player(player_id,True),text)))

                        boxsizer.AddSizer(fgs, 1, wxALL |wxEXPAND, 5)
                        psizer.AddSizer(boxsizer, pos[2], wxALL |wxEXPAND, 5)

                totsizer.AddSizer(psizer, 0, wxALIGN_LEFT | wxALL | wxEXPAND, 5)

        # Ok / Cancel buttons

        self.SetSizer(totsizer)
        self.SetAutoLayout(True)
        totsizer.Fit(self)
