# -*- coding: iso-8859-1 -*-

# Mattricks, a free helper program for hattricks players.
# Copyright (C) 2003 Mattricks Team
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import os, os.path
import time

from Common import *

from Images import Images, create_star_image
import DataInfo
import HRFData
import Terms
import Columndialog
import SelectDateMenu
import PlayerDialog

from Config import config
from Configdialog import apply_function_list

from wxPython.wx import *
from wxPython.lib.mixins.listctrl import wxColumnSorterMixin, wxListCtrlAutoWidthMixin

# "attribute": (colflags, sort_increasing_order)
# attribute   - The attribute in the player object.
# colflags    - Column flags (None if no flags).
# sort_increasing_order - If the column should be sorted in increasing order
playerlist_columns = {
    "name": (None, True),
    "playerID": (wxLIST_FORMAT_RIGHT, True),
    "ald": (wxLIST_FORMAT_RIGHT, True),
    "CountryID": (wxLIST_FORMAT_RIGHT, True),
    "warnings": (wxLIST_FORMAT_RIGHT, False),
    "ska": (wxLIST_FORMAT_RIGHT, False),
    "rating": (wxLIST_FORMAT_RIGHT, False),
    "for": (None, False),
    "TrainerSkill": (None, False),
    "uth": (None, False),
    "mlv": (None, False),
    "spe": (None, False),
    "fra": (None, False),
    "ytt": (None, False),
    "bac": (None, False),
    "mal": (None, False),
    "fas": (None, False),
    "rut": (None, False),
    "led": (None, False),
    "sal": (wxLIST_FORMAT_RIGHT, False),
    "mkt": (wxLIST_FORMAT_RIGHT, False),
    "speciality": (None, True),
    "gentleness": (None, True),
    "honesty": (None, True),
    "Aggressiveness": (None, True),
    "gtl": (wxLIST_FORMAT_RIGHT,False),
    "gtc": (wxLIST_FORMAT_RIGHT,False),
    "gttot": (wxLIST_FORMAT_RIGHT,False),
    "gtt": (wxLIST_FORMAT_RIGHT,False),
    "gtall": (wxLIST_FORMAT_RIGHT,False),
    "gev": (wxLIST_FORMAT_RIGHT,False),
    "hat": (wxLIST_FORMAT_RIGHT,False),
    "ts_best_position": (None, True),
    "ts_goalie": (wxLIST_FORMAT_RIGHT, False),
    "ts_centraldefender": (wxLIST_FORMAT_RIGHT, False),
    "ts_centraldefender_offensive": (wxLIST_FORMAT_RIGHT, False),
    "ts_centraldefender_towards_the_wing": (wxLIST_FORMAT_RIGHT, False),
    "ts_wingback": (wxLIST_FORMAT_RIGHT, False),
    "ts_wingback_offensive": (wxLIST_FORMAT_RIGHT, False),
    "ts_wingback_defensive": (wxLIST_FORMAT_RIGHT, False),
    "ts_wingback_towards_the_middle": (wxLIST_FORMAT_RIGHT, False),
    "ts_innermid": (wxLIST_FORMAT_RIGHT, False),
    "ts_innermid_offensive": (wxLIST_FORMAT_RIGHT, False),
    "ts_innermid_defensive": (wxLIST_FORMAT_RIGHT, False),
    "ts_innermid_towards_the_wing": (wxLIST_FORMAT_RIGHT, False),
    "ts_winger": (wxLIST_FORMAT_RIGHT, False),
    "ts_winger_offensive": (wxLIST_FORMAT_RIGHT, False),
    "ts_winger_defensive": (wxLIST_FORMAT_RIGHT, False),
    "ts_winger_towards_the_middle": (wxLIST_FORMAT_RIGHT, False),
    "ts_forward": (wxLIST_FORMAT_RIGHT, False),
    "ts_forward_defensive": (wxLIST_FORMAT_RIGHT, False)
    }

# Different column lists:
column_lists = {

    "custom": (N_("User defined"),
               config.get("Player list", "custom playerlist columns")),

    "attributes": (N_("Player attributes"),
                   ["name", "playerID", "ald", "CountryID", "warnings", "ska",
                    "rating", "for", "TrainerSkill", "uth", "mlv", "spe",
                    "fra", "ytt", "bac", "mal", "fas", "rut", "led", "sal",
                    "mkt", "speciality", "gentleness", "honesty",
                    "Aggressiveness"]),

    "goals": (N_("Goals"),
              ["name", "gtl", "gtc", "gttot", "gtt", "gtall", "gev", "hat"]),

    "evaluation": (N_("Player evaluation"),
                   ["name", "ts_best_position", "ts_goalie",
                    "ts_centraldefender", "ts_centraldefender_offensive",
                    "ts_centraldefender_towards_the_wing", "ts_wingback",
                    "ts_wingback_offensive", "ts_wingback_defensive",
                    "ts_wingback_towards_the_middle", "ts_innermid",
                    "ts_innermid_offensive", "ts_innermid_defensive",
                    "ts_innermid_towards_the_wing", "ts_winger",
                    "ts_winger_offensive", "ts_winger_defensive",
                    "ts_winger_towards_the_middle", "ts_forward",
                    "ts_forward_defensive"])
    }

class PlayerListCtrl(wxListCtrl, wxListCtrlAutoWidthMixin):
    def __init__(self, parent, ID, pos=wxDefaultPosition,
                 size=wxDefaultSize, style=0):
        wxListCtrl.__init__(self, parent, ID, pos, size, style)
        wxListCtrlAutoWidthMixin.__init__(self)

class PlayerListCtrlPanel(wxPanel):
    def __init__(self, parent, htdata, column_list):
        self.htdata = htdata
        self.column_info = playerlist_columns
        self.curr_col_list = column_list
        self.sort_column = -1
        self.sort_colname = ""

        wxPanel.__init__(self, parent, -1)

        tID = wxNewId()

        self.list = PlayerListCtrl(self, tID,
                                   style=wxLC_REPORT | wxSUNKEN_BORDER
                                   | wxLC_VRULES | wxLC_HRULES | wxLC_SINGLE_SEL
                                   )

        if wxPlatform != '__WXMSW__':
            self.imagelist = wxImageList(20, 12)
            self.images = {
                "up":   self.imagelist.Add(Images.get_bitmap_from_file("arrow_small_up.png")),
                "down": self.imagelist.Add(Images.get_bitmap_from_file("arrow_small_down.png")),
                "yellowcard": self.imagelist.Add(Images.get_bitmap_from_file("yellowcard.png")),
                "2yellowcards": self.imagelist.Add(Images.get_bitmap_from_file("2yellowcards.png")),
                "redcard": self.imagelist.Add(Images.get_bitmap_from_file("redcard.png"))
                }

            self.stars = {}
            for i in range(1,31):
                self.stars[i] = self.imagelist.Add(create_star_image(i))

            self.flags = {}
            for cid, cinfo in DataInfo.country_info.items():
                flagfile = cinfo[5]
                if flagfile != None:
                    bmp = Images.get_bitmap_from_file(flagfile)
                    self.flags[cid] = self.imagelist.Add(bmp)

            self.list.SetImageList(self.imagelist, wxIMAGE_LIST_SMALL)

        self.columns_increasing_sort = {}

        for attribute, (colflags, sort_increasing) in self.column_info.items():
            self.columns_increasing_sort[attribute] = sort_increasing

        self.UpdateColumns()

        EVT_SIZE(self, self.OnSize)
        EVT_LIST_ITEM_RIGHT_CLICK(self, tID, self.OnItemRightClick)
        EVT_LIST_COL_CLICK(self, tID, self.OnColClick)

    def OnSize(self, event):
        w,h = self.GetClientSizeTuple()
        self.list.SetDimensions(0, 0, w, h)

    def OnItemRightClick(self, event):
        pid = self.pid_list[event.GetData()]
        dlg = PlayerDialog.PlayerDialog(self, self.htdata, pid)
        ret = dlg.Show()


    def OnColClick(self, event):
        self.SortList(event.GetColumn(), False)

    def PopulateList(self):
        if self.htdata == None:
            return

        self.pid_list=[]
        x = 0
        for pid in self.htdata.get_pids():
            self.pid_list.append(pid)
            self.list.InsertImageStringItem(x, getattr(self.htdata.get_player(pid, True), \
                                                       "name"), -1)
            y = 0
            for attribute in self.curr_col_list:
                (colflags, sort_increasing) = self.column_info[attribute]
                colname = DataInfo.known_player_data_info[attribute][1]
                if attribute in self.curr_col_list:
                    cvalue = getattr(self.htdata.get_player(pid), attribute)
                    dvalue = getattr(self.htdata.get_player(pid, True), attribute)
                    if dvalue == None:
                        value = ""
                    else:
                        value = dvalue
                    if wxPlatform != '__WXMSW__':
                        if attribute == "warnings":
                            if 0 < cvalue <= 3:
                                img = self.images[{1: "yellowcard",
                                                   2: "2yellowcards",
                                                   3: "redcard"}[cvalue]]
                                self.list.SetStringItem(x, y, "", img)
                            else:
                                self.list.SetStringItem(x, y, "")
                        elif attribute == "CountryID":
                            cid = Terms.country[cvalue]
                            if cid in self.flags.keys():
                                img = self.flags[cid]
                                self.list.SetStringItem(x, y, "", img)
                            else:
                                self.list.SetStringItem(x, y, value)
                        elif attribute == "rating":
                            if 0 < cvalue <= 30:
                                img = self.stars[cvalue]
                                self.list.SetStringItem(x, y, value, img)
                            elif cvalue == 0:
                                self.list.SetStringItem(x, y, "")
                            else:
                                self.list.SetStringItem(x, y, value)
                        else:
                            self.list.SetStringItem(x, y, value)
                    else:
                        self.list.SetStringItem(x, y, value)
                    y += 1
            self.list.SetItemData(x, x)
            x += 1

    def SortList(self, column, resort):
        if column == -1:
            column = 0
        old_col = self.sort_column
        real_col = self.__get_column_attribute(column)
        if real_col == None:
            return
        HRFData.player_sort_attribute = real_col
        self.sort_column = column
        self.sort_colname = DataInfo.known_player_data_info[real_col][1]
        if not resort and old_col == column:
            self.ascending = not self.ascending
            self.columns_increasing_sort[real_col] = self.ascending
        elif old_col != column:
            self.ascending = self.columns_increasing_sort[real_col]
        self.list.SortItems(self.__column_sorter)
        self.__update_column_images(old_col)

    def UpdateColumns(self):
        self.list.ClearAll()
        info = wxListItem()
        info.m_mask = wxLIST_MASK_TEXT | wxLIST_MASK_FORMAT
        if wxPlatform != '__WXMSW__':
            info.m_mask |= wxLIST_MASK_IMAGE
        info.m_image = -1
        new_sortcol = -1
        self.col_ids = {}
        i = 0
        for attribute in self.curr_col_list:
            (colflags, sort_increasing) = self.column_info[attribute]
            colname = DataInfo.known_player_data_info[attribute][1]
            if attribute in self.curr_col_list:
                if colflags == None:
                    info.m_format = 0
                else:
                    info.m_format = colflags
                info.m_text = colname
                self.list.InsertColumnInfo(i, info)
                self.col_ids[i] = attribute
                if self.sort_colname == colname:
                    new_sortcol = i
                i += 1

        self.PopulateList()
        self.SortList(new_sortcol, True)

        for i in range(len(self.col_ids)):
            self.list.SetColumnWidth(i, wxLIST_AUTOSIZE)

    def __get_column_attribute(self, index):
        if not self.col_ids.has_key(index):
            return None
        return self.col_ids[index]

    def __column_sorter(self, key1, key2):
        p1 = self.htdata.get_player(self.pid_list[key1])
        p2 = self.htdata.get_player(self.pid_list[key2])
        if p1 > p2:
            res = 1
        elif p1 < p2:
            res = -1
        else:
            res = 0

        if not self.ascending:
            res = -res

        return res

    def __update_column_images(self, old_col):
        if wxPlatform == '__WXMSW__':
            return

        if old_col != -1:
            self.list.ClearColumnImage(old_col)
        if self.sort_column != -1:
            img = self.images[{True: "down", False: "up"}[self.ascending]]
            self.list.SetColumnImage(self.sort_column, img)


class PlayerPage(wxPanel):
    ID_POPUP_MENU = 211
    ID_DATE_SELECTED = 212
    ID_EDIT_COLUMNS = 213
    ID_LISTCHOICE = 214

    def __init__(self, parent, ID, filename):
        if filename == None:
            self.htdata = (None, None)
        else:
            self.htdata = (filename, HRFData.hrfstorage[filename])

        wxPanel.__init__(self, parent, ID)

        sizer = wxBoxSizer(wxVERTICAL)
        hsizer = wxBoxSizer(wxHORIZONTAL)
        vsizer = wxBoxSizer(wxVERTICAL)

        self.htbutton = wxButton(self, PlayerPage.ID_POPUP_MENU, \
                                 _("Change date"), style = wxBU_EXACTFIT)
        vsizer.Add(self.htbutton, 0, wxALIGN_CENTRE | wxALL, 5)

        button = wxButton(self, PlayerPage.ID_EDIT_COLUMNS, _("Edit columns"), \
                          style = wxBU_EXACTFIT)
        vsizer.Add(button, 0, wxALIGN_CENTRE | wxALL, 5)

        hsizer.AddSizer(vsizer, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 0)

        self.current_hrf_info = wxStaticText(self, -1, self.__get_current_text())
        hsizer.Add(self.current_hrf_info, 1, wxEXPAND | wxALL, 5)

        stext = wxStaticText(self, -1, _("Choose what columns to view") + ":")
        hsizer.Add(stext, 0, wxALIGN_CENTRE | wxALL, 5)

        self.cl = dict([(_(descr), name) for name, (descr, the_list) in \
                        column_lists.items()])
        choices = self.cl.keys()
        choices.reverse()
        self.choice_of_list = wxChoice(self, self.ID_LISTCHOICE, choices = choices)
        hsizer.Add(self.choice_of_list, 0, wxALIGN_CENTRE | wxALL, 5)

        sizer.AddSizer(hsizer, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 0)

        self.playerlist = PlayerListCtrlPanel(self, self.htdata[1],
                                              self.__get_current_list())
        sizer.Add(self.playerlist, 1, wxEXPAND | wxALL, 1)

        self.SetSizer(sizer)
        self.SetAutoLayout(True)
        sizer.Fit(self)

        EVT_BUTTON(self, PlayerPage.ID_POPUP_MENU, self.OnPopupMenu)
        EVT_BUTTON(self, PlayerPage.ID_EDIT_COLUMNS, self.OnEditCol)
        EVT_CHOICE(self, PlayerPage.ID_LISTCHOICE, self.ChangeList)

        apply_function_list.append(self.ConfigChanged)

    def __del__(self):
        apply_function_list.remove(self.ConfigChanged)

    def ChangeHRF(self, hrffile):
        self.htdata = (hrffile, HRFData.hrfstorage[hrffile])
        self.playerlist.htdata = self.htdata[1]
        self.playerlist.UpdateColumns()
        self.current_hrf_info.SetLabel(self.__get_current_text())

    def OnEditCol(self, event):
        cl = column_lists["custom"][1]
        hl = []
        tl = []
        for c in playerlist_columns.keys():
            if c not in cl:
                hl.append(c)
            tl.append(c)

        tl = dict([(DataInfo.known_player_data_info[c][1], c) for c in tl])
        cl = [DataInfo.known_player_data_info[c][1] for c in cl]
        hl = [DataInfo.known_player_data_info[c][1] for c in hl]

        dlg = Columndialog.ColumnDialog(cl, hl)
        ret = dlg.ShowModal()
        if ret == wxID_OK:
            cl = dlg.GetEnabledStrings()
            cl = [tl[c] for c in cl]
            cdescr = column_lists["custom"][0]
            self.choice_of_list.SetStringSelection(_(cdescr))
            column_lists["custom"] = (cdescr, cl)
            config.set("Player list", "custom playerlist columns", cl)
            self.playerlist.curr_col_list = cl
            self.playerlist.UpdateColumns()
        dlg.Destroy()

    def OnPopupMenu(self, event):
        sdmenu = SelectDateMenu.SelectDateMenu(self, PlayerPage.ID_DATE_SELECTED, self.htdata[0])
        SelectDateMenu.EVT_DATE_SELECTED(sdmenu, PlayerPage.ID_DATE_SELECTED, \
                                         self.OnDateSelected)
        rect = self.htbutton.GetRect()
        self.PopupMenu(sdmenu, (rect[0], rect[1] + rect[3]))

    def OnDateSelected(self, event):
        self.ChangeHRF(event.GetHRFFile())

    def ChangeList(self, event):
        self.playerlist.curr_col_list = self.__get_current_list()
        self.playerlist.UpdateColumns()

    def ConfigChanged(self, changed_vars):
        if not (changed_vars.has_key("Player list") and
                "custom playerlist columns" in changed_vars["Player list"]):
            return

        if self.playerlist.curr_col_list == column_lists["custom"][1]:
            update = True
        else:
            update = False
        column_lists["custom"] = (column_lists["custom"][0],
                                  config.get("Player list", "custom playerlist columns"))
        if update:
            self.playerlist.curr_col_list = self.__get_current_list()
            self.playerlist.UpdateColumns()

    def __get_current_text(self):
        return htdata_text(self.htdata)

    def __get_current_list(self):
        sl = self.choice_of_list.GetStringSelection()
        if not sl:
            return []
        return column_lists[self.cl[sl]][1]
