# -*- coding: iso-8859-1 -*-

# Mattricks, a free helper program for hattricks players.
# Copyright (C) 2003 Mattricks Team
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import HRFData
from LineupCtrl import LineupCtrl
import SelectDateMenu
import TeamSelector
import Terms

from Common import *
from Commonwx import *

from wxPython.wx import *

class TeamSelectorPage(wxPanel):
    ID_POPUP_MENU    = 301
    ID_DATE_SELECTED = 302
    ID_CALC_TEAM     = 303

    def __init__(self, parent, ID, filename):
        if filename == None:
            self.htdata = (None, None)
        else:
            self.htdata = (filename, HRFData.hrfstorage[filename])

        wxPanel.__init__(self, parent, ID)

        sizer = wxBoxSizer(wxVERTICAL)
        hsizer = wxBoxSizer(wxHORIZONTAL)

        self.htbutton = wxButton(self, TeamSelectorPage.ID_POPUP_MENU, \
                                 _("Change date"), style = wxBU_EXACTFIT)
        hsizer.Add(self.htbutton, 0, wxALIGN_CENTRE | wxALL, 5)

        self.current_hrf_info = wxStaticText(self, -1, self.__get_current_text())
        hsizer.Add(self.current_hrf_info, 1, wxEXPAND | wxALL, 5)

        sizer.AddSizer(hsizer, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 0)

        hsizer = wxBoxSizer(wxHORIZONTAL)

        self.calc_button = wxButton(self, TeamSelectorPage.ID_CALC_TEAM, \
                                    _("Let the copmuter pick a team"), style = wxBU_EXACTFIT)
        hsizer.Add(self.calc_button, 0, wxALIGN_CENTRE | wxALL, 5)

        ttext = wxStaticText(self, -1, _("Team value") + ":")
        hsizer.Add(ttext, 0, wxEXPAND | wxADJUST_MINSIZE | wxALL, 5)

        self.teamval_text = wxStaticText(self, -1, "")
        hsizer.Add(self.teamval_text, 1, wxEXPAND | wxADJUST_MINSIZE | wxALL, 5)

        sizer.AddSizer(hsizer, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 0)

        self.lineup = LineupCtrl(self, -1, False, "teamselect", None)
        sizer.Add(self.lineup, 1, wxEXPAND | wxALIGN_CENTRE | wxALL, 5)

        self.SetSizer(sizer)
        self.SetAutoLayout(True)
        sizer.Fit(self)

        EVT_BUTTON(self, TeamSelectorPage.ID_POPUP_MENU, self.OnPopupMenu)
        EVT_BUTTON(self, TeamSelectorPage.ID_CALC_TEAM, self.OnCalcTeam)

    def ChangeHRF(self, hrffile):
        self.htdata = (hrffile, HRFData.hrfstorage[hrffile])
        self.current_hrf_info.SetLabel(self.__get_current_text())
        self.lineup.ChangeHRF("teamselect", None)
        self.teamval_text.SetLabel("")

        self.Refresh()

    def OnPopupMenu(self, event):
        sdmenu = SelectDateMenu.SelectDateMenu(self, TeamSelectorPage.ID_DATE_SELECTED, self.htdata[0])
        SelectDateMenu.EVT_DATE_SELECTED(sdmenu, TeamSelectorPage.ID_DATE_SELECTED, \
                                         self.OnDateSelected)
        rect = self.htbutton.GetRect()
        self.PopupMenu(sdmenu, (rect[0], rect[1] + rect[3]))

    def OnDateSelected(self, event):
        self.ChangeHRF(event.GetHRFFile())

    def OnCalcTeam(self, event):
        if self.htdata == (None, None):
            return

        ts = TeamSelector.TeamSelector(self.htdata[1])
        lineup = ts.select_team()
        self.lineup.ChangeHRF("teamselect", lineup, self.htdata[1])
        self.teamval_text.SetLabel("%.2f" % ts.de.teamval(lineup))

        self.Refresh()

    def __get_current_text(self):
        return htdata_text(self.htdata)
