# -*- coding: iso-8859-1 -*-

# Mattricks, a free helper program for hattricks players.
# Copyright (C) 2003 Mattricks Team
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from Common import *

import cStringIO
import os
import os.path
import re
import string
import sys

from xml.sax import saxlib, saxexts

def team_cmp(t1, t2):
    v = t2[6] - t1[6]
    if v == 0:
        v = (t2[4]-t2[5]) - (t1[4]-t1[5])
        if v == 0:
            v = t2[4] - t1[4]
            if v == 0:
                v = t1[8] - t2[8]
    return v

class XMLStore:
    def __init__(self):
        self.fixtures = {}

    def get(self, f):
        t = os.path.getmtime(f)
        if self.fixtures.has_key(f):
            x, ot = self.fixtures[f]
            if t == ot:
                return x
        self.fixtures[f] = (parse_fixtures(f), t)
        return self.fixtures[f][0]

class XMLDir:
    re_fixture_filename = re.compile("fixtures-([0-9]+)-s([0-9]+).xml", re.IGNORECASE)

    def __init__(self, *dirs):
        self.dirs = []
        self.fixtures_list = {}
        self.add_dirs(*dirs)

    def add_dirs(self, *dirs):
        for cdir in dirs:
            cdir = os.path.realpath(os.path.expanduser(cdir))
            filelist = os.listdir(cdir)
            for f in filelist:
                fp = os.path.join(cdir, f)
                if os.path.isfile(fp):
                    m = XMLDir.re_fixture_filename.search(f)
                    if m:
                        leagueid = int(m.group(1))
                        season = int(m.group(2))

                        if not self.fixtures_list.has_key(leagueid):
                            self.fixtures_list[leagueid] = {}
                        self.fixtures_list[leagueid][season] = fp
            if not cdir in self.dirs:
                self.dirs.append(cdir)

    def get_fixture(self, leagueid, season):
        if not self.fixtures_list.has_key(leagueid) or \
               not self.fixtures_list[leagueid].has_key(season):
            return None
        return self.fixtures_list[leagueid][season]

# The storage
xmlstorage = XMLStore()
# The files
xmldirs = XMLDir()

class Fixtures:
    def __init__(self,
                 matches = {},
                 filename = "",
                 fetcheddate = -1,
                 actiontype = "",
                 leaguelevelunitid = -1,
                 leaguelevelunitname = "",
                 season = -1):
        self.matches = matches
        self.filename = filename
        self.fetched_date = fetcheddate
        self.action_type = actiontype
        self.league_id = leaguelevelunitid
        self.league_name = leaguelevelunitname
        self.season = season

    def get_league_name(self):
        return self.league_name

    def calc_table(self, round = 14):
        eligible_rounds = filter(lambda x, r=round: 0 < x <= r, self.matches.keys())
        eligible_rounds.sort()

        def team_add(orig, add):
            res = []
            for i in range(7):
                res.append(orig[i] + add[i])
            res.append(add[7])
            return res

        # id: played, wins, draws, lost, goals_for, goals_against, points, name
        teams = {}
        hteams = {}
        ateams = {}

        for r in eligible_rounds:
            for m_id, vals in self.matches[r].items():
                hid = vals["hometeamid"]
                aid = vals["awayteamid"]

                hgoals = vals["homegoals"]
                agoals = vals["awaygoals"]

                if hgoals < 0 or agoals < 0:
                    hadd = [0, 0, 0, 0, 0, 0, 0, vals["hometeamname"]]
                    aadd = [0, 0, 0, 0, 0, 0, 0, vals["awayteamname"]]
                else:
                    if hgoals == agoals:
                        h_wdl = [0, 1, 0]
                        a_wdl = [0, 1, 0]
                        hp = 1
                        ap = 1
                    elif hgoals > agoals:
                        h_wdl = [1, 0, 0]
                        a_wdl = [0, 0, 1]
                        hp = 3
                        ap = 0
                    else:
                        h_wdl = [0, 0, 1]
                        a_wdl = [1, 0, 0]
                        hp = 0
                        ap = 3

                    hadd = [1] + h_wdl + [hgoals, agoals, hp, vals["hometeamname"]]
                    aadd = [1] + a_wdl + [agoals, hgoals, ap, vals["awayteamname"]]

                if not teams.has_key(hid):
                    teams[hid] = hadd
                else:
                    teams[hid] = team_add(teams[hid], hadd)

                # Home games
                if not hteams.has_key(hid):
                    hteams[hid] = hadd
                else:
                    hteams[hid] = team_add(hteams[hid], hadd)

                if not teams.has_key(aid):
                    teams[aid] = aadd
                else:
                    teams[aid] = team_add(teams[aid], aadd)

                # Away games
                if not ateams.has_key(aid):
                    ateams[aid] = aadd
                else:
                    ateams[aid] = team_add(ateams[aid], aadd)

        teams = [v + [k] for k, v in teams.items()]
        teams.sort(team_cmp)

        hteams = [v + [k] for k, v in hteams.items()]
        hteams.sort(team_cmp)

        ateams = [v + [k] for k, v in ateams.items()]
        ateams.sort(team_cmp)

        return (teams, hteams, ateams)

    def write_table_text(self, outfile, round = 14):
        (teams, hteams, ateams) = self.calc_table(round)

        outfile.write("%-30s %7s %2s %2s %2s %2s %3s - %3s %2s\n" % \
                      (_("Name"), _("Id"), _("Pl"), _("W"), _("D"),
                       _("L"), _("F"), _("A"), _("Po")))
        outfile.write("-"*63 + "\n")
        for pl, w, d, l, f, a, po, n, tid in teams:
            outfile.write("%-30s %7d %2d %2d %2d %2d %3d - %3d %2d\n" % \
                          (n, tid, pl, w, d, l, f, a, po))

class HTFixturesHandler(saxlib.HandlerBase):
    content_elements = {"filename": None,
                        "fetcheddate": string2time,
                        "actiontype": None,
                        "leaguelevelunitid": int,
                        "leaguelevelunitname": None,
                        "season": int,
                        "matchround": int,
                        "hometeamid": int,
                        "hometeamname": None,
                        "awayteamid": int,
                        "awayteamname": None,
                        "matchdate": string2time,
                        "homegoals": int,
                        "awaygoals": int}

    def __init__(self):
        self.__reset()

    def startDocument(self):
        self.__reset()

    def endDocument(self):
        self.other_data["matches"] = self.matches
        self.fixtures = Fixtures(**self.other_data)

    def startElement(self, name, attrs):
        try:
            name = name.lower().encode("iso8859-1")
        except:
            name = name.lower().encode("utf8")
        if name == "hattrickdata":
            self.inhattrickdata = True
            return

        if not self.inhattrickdata:
            return

        if name == "match":
            self.inmatch = True
            self.match_id = -1
            self.match_round = -1
            self.match_data = {"hometeamid": -1,
                               "hometeamname": "",
                               "awayteamid": -1,
                               "awayteamname": "",
                               "matchdate": -1,
                               "homegoals": -1,
                               "awaygoals": -1}

            if attrs.has_key("ID"):
                self.match_id = int(attrs["ID"])

        if name in self.content_elements.keys():
            self.get_content = True
            self.contentdata = ""

    def endElement(self, name):
        try:
            name = name.lower().encode("iso8859-1")
        except:
            name = name.lower().encode("utf8")
        if name == "hattrickdata":
            self.inhattrickdata = False
            return

        if not self.inhattrickdata:
            return

        if name == "match":
            if not self.match_round in self.matches.keys():
                self.matches[self.match_round] = {}
            self.matches[self.match_round][self.match_id] = self.match_data
            self.inmatch = False
            self.match_data = None

        if name in self.content_elements.keys():
            self.get_content = True
            func = self.content_elements[name]
            try:
                c = self.contentdata.encode("iso8859-1")
            except:
                c = self.contentdata.encode("utf8")
            if func != None:
                try:
                    c = func(c)
                except ValueError, e:
                    pass

            if self.inmatch:
                if name == "matchround":
                    self.match_round = c
                else:
                    self.match_data[name] = c
            else:
                self.other_data[name] = c

    def characters(self, content, offset, length):
        self.contentdata += content[offset:offset+length]

    def __reset(self):
        self.inhattrickdata = False
        self.inmatch = False
        self.match_id = -1
        self.match_round = -1
        self.match_data = None
        self.get_content = False
        self.contentdata = ""
        self.fixtures = None

        self.matches = {}
        self.other_data = {}

def parse_fixtures(xmlfile):
    handler = HTFixturesHandler()
    parser = saxexts.make_parser()

    parser.setDocumentHandler(handler)
    inFile = file(xmlfile, 'r')

    # Start the parse.
    parser.parseFile(inFile)
    inFile.close()

    return handler.fixtures

def parse_string_fixtures(xmldata):
    handler = HTFixturesHandler()
    parser = saxexts.make_parser()

    parser.setDocumentHandler(handler)
    inFile = cStringIO.StringIO(xmldata)

    # Start the parse.
    parser.parseFile(inFile)
    inFile.close()

    return handler.fixtures
